@@ -8,7 +8,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  ***************************************************************************/
 
 // Do not introduce any Qt or KDE dependencies into the "CT"-prefixed classes.
@@ -23,17 +23,31 @@
 #include <fstream.h>     // ifstream, istream, ostream
 #include <unistd.h>      // getuid(), unlink()
 #include <pwd.h>         // pwd, getpwnam(), getpwuid()
-#include <stdio.h>       // sprintf()
+#include <stdio.h>
+#include <qfile.h>       // sprintf()
+
+#ifdef KDE_FIXES
+#include <ktempfile.h>
+#endif
+
+using namespace std;
 
 CTCron::CTCron(bool _syscron, string _login) :
   syscron(_syscron)
 {
   int uid(getuid());
 
+#ifdef KDE_FIXES
+  KTempFile tmp;
+  tmp.setAutoDelete(true);
+  tmp.close();
+  tmpFileName = string(QFile::encodeName(tmp.name()));  
+#else
   char ofile[20] = "/tmp/crontab.XXXXXX";
   sprintf (ofile+13,"%d",getpid());
 
   tmpFileName = string(ofile);
+#endif
 
   string readCommand;
   passwd *pwd;
@@ -94,14 +108,14 @@ void CTCron::operator = (const CTCron& source)
   if (source.syscron)
     throw CTException();
 
-  for (CTVariableIterator i = (CTVariableIterator)source.variable.begin();
+  for (CTVariableIterator i = const_cast<CTCron&>(source).variable.begin();
     i != source.variable.end(); i++)
   {
     CTVariable* tmp = new CTVariable(**i);
     variable.push_back(tmp);
   }
 
-  for (CTTaskIterator i = (CTTaskIterator)source.task.begin();
+  for (CTTaskIterator i = const_cast<CTCron&>(source).task.begin();
     i != source.task.end(); i++)
   {
     CTTask* tmp = new CTTask(**i);
@@ -124,16 +138,24 @@ istream& operator >> (istream& inputStream, CTCron& cron)
     // search for comments "#" but not disabled tasks "#\"
     if ((line.find("#") == 0) && (line.find("\\") != 1))
     {
-      // remove leading pound sign
-      line = line.substr(1,line.length()-1);
+      // If the first 10 characters don't contain a character, it's probably a disabled entry.
+      int first_text = line.find_first_of("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
+      if (first_text < 0)
+         continue;
 
-      // remove leading whitespace
-      while (line.find_first_of(" \t") == 0)
-        line = line.substr(1,line.length()-1);
-
-      comment = line;
+      if (first_text < 10) 
+      {
+         // remove leading pound sign
+         line = line.substr(1,line.length()-1);
+         // remove leading whitespace
+         while (line.find_first_of(" \t") == 0)
+            line = line.substr(1,line.length()-1);
+         comment = line;
+         continue;
+      }
     }
-    else
+
+    // else
     {
       // either a task or a variable
       int firstWhiteSpace(line.find_first_of(" \t"));
@@ -169,14 +191,14 @@ ostream& operator << (ostream& outputStream, const CTCron& cron)
 {
   int itemCount(0);
 
-  for (CTVariableIterator i = (CTVariableIterator)cron.variable.begin();
+  for (CTVariableIterator i = const_cast<CTCron&>(cron).variable.begin();
     i != cron.variable.end(); i++)
   {
     outputStream << **i;
     itemCount++;
   }
 
-  for (CTTaskIterator i = (CTTaskIterator)cron.task.begin();
+  for (CTTaskIterator i = const_cast<CTCron&>(cron).task.begin();
     i != cron.task.end(); i++)
   {
     outputStream << **i;
@@ -221,6 +243,9 @@ void CTCron::apply()
 
   for (CTVariableIterator i = variable.begin(); i != variable.end(); i++)
     (*i)->apply();
+
+  initialTaskCount = task.size();
+  initialVariableCount = variable.size();
 }
 
 void CTCron::cancel()
@@ -253,7 +278,7 @@ string CTCron::path() const
 {
   string path;
 
-  for (CTVariableIterator var = (CTVariableIterator)variable.begin();
+  for (CTVariableIterator var = const_cast<CTCron*>(this)->variable.begin();
     var != variable.end(); var++)
   {
     if ((*var)->variable == "PATH")
