@@ -8,7 +8,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  ***************************************************************************/
 
 #include "kttask.h"
@@ -22,7 +22,7 @@
 #include <qpushbutton.h>
 #include <qbuttongroup.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 #include <klocale.h>
 #include <kfiledialog.h>
@@ -32,7 +32,7 @@
 
 #include "kticon.h"
 
-KTTask::KTTask(CTTask* _cttask)
+KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   : KDialog( 0, "kttask", true, WStyle_DialogBorder )
 {
   cttask = _cttask;
@@ -81,7 +81,7 @@ KTTask::KTTask(CTTask* _cttask)
 
   // command
   QHBoxLayout *h3 = new QHBoxLayout( ml, KDialogBase::spacingHint() );
-  
+
   labCommand = new QLabel( i18n("&Program:"), this, "labCommand" );
   h3->addWidget( labCommand );
 
@@ -105,6 +105,11 @@ KTTask::KTTask(CTTask* _cttask)
   chkEnabled->setChecked(cttask->enabled);
   ml->addWidget( chkEnabled );
 
+  // enabled
+  chkSilent = new QCheckBox(i18n("&Silent"), this, "chkSilent");
+  chkSilent->setChecked(cttask->silent);
+  ml->addWidget( chkSilent );
+
   QHBoxLayout *h4 = new QHBoxLayout( ml, KDialogBase::spacingHint() );
 
   ml->addSpacing( 2 * KDialogBase::spacingHint() );
@@ -127,7 +132,7 @@ KTTask::KTTask(CTTask* _cttask)
   }
 
   QVBoxLayout *v1 = new QVBoxLayout( h4, KDialogBase::spacingHint() );
-  
+
   // days of the month
   bgDayOfMonth = new QButtonGroup( i18n("Days of the Month"), this, "bgDayOfMonth");
   v1->addWidget( bgDayOfMonth );
@@ -138,7 +143,7 @@ KTTask::KTTask(CTTask* _cttask)
   QVBoxLayout *vdays = new QVBoxLayout( bgDayOfMonth, KDialogBase::spacingHint() );
   vdays->addSpacing( 2 * KDialogBase::spacingHint() );
   QHBoxLayout *hdays = 0;
- 
+
   for (int dm = 1; dm <= 31; dm++)
   {
     if( (dm % 7) == 1 )
@@ -162,7 +167,7 @@ KTTask::KTTask(CTTask* _cttask)
 
   QVBoxLayout *v3 = new QVBoxLayout( bgDayOfWeek, KDialogBase::spacingHint() );
   v3->addSpacing( 2 * KDialogBase::spacingHint() );
-  
+
   for (int dw = 1; dw <= 7; dw++)
   {
     cbDayOfWeek[dw] = new QCheckBox(bgDayOfWeek);
@@ -181,7 +186,7 @@ KTTask::KTTask(CTTask* _cttask)
 
   QVBoxLayout *v9 = new QVBoxLayout( bgEveryDay, KDialogBase::spacingHint() );
   v9->addSpacing( 2 * KDialogBase::spacingHint() );
-  
+
   cbEveryDay = new QCheckBox( i18n("Run Every Day"), bgEveryDay, "cbEveryDay");
   cbEveryDay->setChecked(everyDay);
   v9->addWidget( cbEveryDay );
@@ -218,18 +223,18 @@ KTTask::KTTask(CTTask* _cttask)
   labPM = new QLabel( i18n("PM"), bgHour, "labPM");
   labPM->setAlignment(AlignRight | AlignVCenter);
   v4->addWidget( labPM );
- 
-  hhours = new QHBoxLayout( v4, KDialogBase::spacingHint() );  
+
+  hhours = new QHBoxLayout( v4, KDialogBase::spacingHint() );
   for (int ho1 = 12; ho1 <= 23; ho1++)
   {
     if( ho1 == 18 )
       hhours = new QHBoxLayout( v4, KDialogBase::spacingHint() );
 
     hhours->addWidget( pbHour[ho1] );
-  }                                                                                                              
+  }
   // minutes
   bgMinute = new QButtonGroup( i18n("Minutes"), this, "bgMinute");
-  v2->addWidget( bgMinute );  
+  v2->addWidget( bgMinute );
   QVBoxLayout *vmin = new QVBoxLayout( bgMinute, KDialogBase::spacingHint() );
   vmin->addSpacing( 2 * KDialogBase::spacingHint() );
 
@@ -247,8 +252,8 @@ KTTask::KTTask(CTTask* _cttask)
   {
     if( mi1 == 30 )
       hmin = new QHBoxLayout( vmin, KDialogBase::spacingHint() );
-    
-    hmin->addWidget( pbMinute[mi1] ); 
+
+    hmin->addWidget( pbMinute[mi1] );
   }
 
   QHBoxLayout *h5 = new QHBoxLayout( ml, KDialogBase::spacingHint() );
@@ -265,7 +270,7 @@ KTTask::KTTask(CTTask* _cttask)
 
   // window
   setIcon(KTIcon::application(true));
-  setCaption(i18n("Edit Task"));
+  setCaption(_caption/*i18n("Edit Task")*/);
 
   // set focus to first widget
   if (cttask->system())
@@ -456,7 +461,7 @@ void KTTask::slotOK()
     }
     showMessage = true;
   }
-  
+
   valid = false;
   for (int mi1 = 0; mi1 <= 55; mi1+=5)
   {
@@ -472,7 +477,7 @@ void KTTask::slotOK()
     }
     showMessage = true;
   }
-  
+
   if (showMessage)
   {
     KMessageBox::information(this, message);
@@ -493,7 +498,7 @@ void KTTask::slotOK()
     if (!file.isReadable())
     {
       KMessageBox::information(this,
-        i18n("Can not locate program.  Please re-enter."));
+        i18n("Cannot locate program. Please re-enter."));
       leCommand->setFocus();
       return;
     }
@@ -501,7 +506,7 @@ void KTTask::slotOK()
     if (!file.isExecutable())
     {
       KMessageBox::information(this,
-        i18n("Program is not an executable file.  Please re-enter."));
+        i18n("Program is not an executable file. Please re-enter."));
       leCommand->setFocus();
       return;
     }
@@ -520,6 +525,7 @@ void KTTask::slotOK()
   cttask->comment = (const char *)leComment->text().local8Bit();
   cttask->command = (const char *)leCommand->text().local8Bit();
   cttask->enabled = chkEnabled->isChecked();
+  cttask->silent = chkSilent->isChecked();
 
   for (int mo = 1; mo <= 12; mo++)
   {
@@ -558,7 +564,7 @@ void KTTask::slotCancel()
 void KTTask::slotBrowse()
 {
   KURL url = KFileDialog::getOpenURL();
-  
+
   if(!url.isEmpty())
   {
     if(url.isLocalFile())
