@@ -39,7 +39,7 @@ public:
 /**
   * Initialize from CTTask.
   */
-  KTTask(CTTask* _cttask = 0);
+  KTTask(CTTask* _cttask = 0, const QString &_caption="");
 
 /**
   * Destroy.
@@ -101,6 +101,7 @@ private:
   QPushButton*    pbBrowse;
 
   QCheckBox*      chkEnabled;
+  QCheckBox*      chkSilent;
 
   QButtonGroup*   bgMonth;
   QCheckBox*      cbMonth[13];
