@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "Archive.h"
 #include "ArchiveInfoWidget.h"
