@@ -1,7 +1,8 @@
-// $Id: BackupDlg.cpp,v 1.12 2000/11/08 21:05:23 rolandg Exp $
+// $Id: BackupDlg.cpp,v 1.21 2002/01/29 04:13:31 widman Exp $
 //
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,7 +30,7 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
 
@@ -75,9 +76,12 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
     setCaption( i18n( "KDat: Backup" ) );
     setIconText( i18n( "KDat: Backup" ) );
 
-    resize( 500, 300 );
+    resize( 515, 300 );
 
-    const int labelWidth = 96;
+    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g" 
+       so we'll provide that plus some space beyond it. */
+    // const int labelWidth = 96;
+    const int labelWidth = 110;
 
     QFrame* f1 = new QFrame( this );
     f1->setFrameStyle( QFrame::Panel | QFrame::Sunken );
@@ -97,22 +101,22 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
     _timeRemaining = new QLabel( i18n( "00:00:00" ), f2 );
     _timeRemaining->setFixedHeight( _timeRemaining->sizeHint().height() );
 
-    QLabel* lbl3 = new QLabel( i18n( "Total kbytes:" ), f1 );
+    QLabel* lbl3 = new QLabel( i18n( "Total KB:" ), f1 );
     lbl3->setFixedSize( labelWidth, lbl3->sizeHint().height() );
 
     QLabel* totalKbytes = new QLabel( Util::kbytesToString( archiveSize ), f1 );
     totalKbytes->setFixedHeight( totalKbytes->sizeHint().height() );
 
-    QLabel* lbl4 = new QLabel( i18n( "Kbytes written:" ), f2 );
+    QLabel* lbl4 = new QLabel( i18n( "KB written:" ), f2 );
     lbl4->setFixedSize( labelWidth, lbl4->sizeHint().height() );
 
-    _kbytesWritten = new QLabel( i18n( "0k" ), f2 );
+    _kbytesWritten = new QLabel( i18n( "0KB" ), f2 );
     _kbytesWritten->setFixedHeight( _kbytesWritten->sizeHint().height() );
 
     QLabel* lbl5 = new QLabel( i18n( "Transfer rate:" ), f1 );
     lbl5->setFixedSize( labelWidth, lbl5->sizeHint().height() );
 
-    _transferRate = new QLabel( i18n( "0k/min" ), f1 );
+    _transferRate = new QLabel( i18n( "0KB/min" ), f1 );
     _transferRate->setFixedHeight( _transferRate->sizeHint().height() );
 
     QLabel* lbl6 = new QLabel( i18n( "Files:" ), f2 );
@@ -254,16 +258,22 @@ void BackupDlg::show()
         }
     } else {
         // Backup listed files only.
+      /* 2002-01-28 LEW */
+      // printf("Fixing to list the files/dirs to be dumped:\n");
+      /* 2002-01-28 LEW */
         for ( QStringList::Iterator it = _files.begin();
               it != _files.end();
               ++it ) {
+	  /* 2002-01-28 LEW */
+	  // printf("tar argument: \"%s\"\n", (*it).latin1());
+	  /* 2002-01-28 LEW */
             *_proc << *it;
 	    bGoOn = true;
 	}
     }
 
     if (bGoOn == false) {
-        KMessageBox::information(this, i18n("No files to backup. Aborting."));
+        KMessageBox::information(this, i18n("No files to back up. Aborting."));
         slotAbort();
         return;
     }          
@@ -303,6 +313,11 @@ void BackupDlg::slotProcessExited( KProcess* )
     _abort->setEnabled( FALSE );
 }
 
+// the KProcess passes the arguments to tar, and tar's output is piped here.
+// The output is shown to _tarParser->slotData(), which figures out which files
+// are going to tape and their file parameters, and saves these data into
+// kdat's archive.  The raw data are then written to tape with write().
+// 2002-01-27 LEW
 void BackupDlg::slotStdout( KProcess*, char* buf, int len )
 {
     // Don't start throughput timer until the first block of data is written.
@@ -310,6 +325,10 @@ void BackupDlg::slotStdout( KProcess*, char* buf, int len )
         _startTime = time( NULL );
     }
 
+    /* 2002-01-26 LEW */
+    // printf("got a line from tar, length %d bytes...\n", len);
+    /* 2002-01-26 LEW */
+
     // Pass the data through the tar parser to extract the file info.
     _tarParser->slotData( buf, len );
 
@@ -333,6 +352,10 @@ void BackupDlg::slotEntry( const QString& name, int size, int mtime, int record
         _archive->addFile( _fileSize, _fileMTime, _fileStartRecord, record, _fileName );
     }
 
+    /* 2002-01-28 LEW */
+    // printf("BackupDlg::slotEntry called with \"%s\", %d bytes\n", name.latin1(), size);
+    /* 2002-01-28 LEW */
+
     _fileName        = name;
     _fileSize        = size;
     _fileMTime       = mtime;
