@@ -1,7 +1,8 @@
-// $Id: BackupOptDlg.cpp,v 1.5 2000/10/25 23:03:59 rolandg Exp $
+// $Id: BackupOptDlg.cpp,v 1.10 2002/01/20 19:56:13 widman Exp $
 //
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "BackupOptDlg.h"
 #include "BackupProfileWidget.h"
