@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,16 +28,16 @@
 #include <qkeycode.h>
 #include <qlayout.h>
 #include <qtextstream.h>
-#include <qmessagebox.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kiconloader.h>
 #include <kmenubar.h>
+#include <kpopupmenu.h>
 #include <ktoolbar.h>
 #include <kglobal.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
-#include <kstringhandler.h> 
+#include <kstringhandler.h>
 
 #include "ArchiveInfoWidget.h"
 #include "BackupDlg.h"
@@ -66,6 +67,7 @@
 #include "ktreeview.h"
 #include <klocale.h>
 #include <qsplitter.h>
+#include <kstatusbar.h>
 
 #include "KDat.moc"
 
@@ -79,11 +81,16 @@ KDat* KDat::getInstance()
     return _instance;
 }
 
+#define KDAT_HORIZONTAL_LAYOUT
 KDat::KDat()
         : KMainWindow(0), _destroyed( FALSE )
 {
-    resize( 600, 400 );
-    
+#ifdef KDAT_HORIZONTAL_LAYOUT      /* 2002-01-20 LEW */
+    resize( 600, 600 );            /* was 600 by 400 */
+#else
+    resize( 600, 600 );
+#endif /* KDAT_HORIZONTAL_LAYOUT */
+
     setIconText( i18n( "KDat: <no tape>" ) );
     setCaption( i18n( "KDat: <no tape>" ) );
 
@@ -112,7 +119,7 @@ KDat::KDat()
 
     _tapeMenu = new QPopupMenu();
     _tapeMenu->insertItem( i18n( "Delete Tape Index" ), this, SLOT( fileDeleteIndex() ) );
-    
+
     _backupProfileRootMenu = new QPopupMenu();
     _backupProfileRootMenu->insertItem( i18n( "Create Backup Profile" ), this, SLOT( fileNewBackupProfile() ) );
 
@@ -120,7 +127,7 @@ KDat::KDat()
     _backupProfileMenu->insertItem( i18n( "Backup..." ), this, SLOT( fileBackup() ) );
     _backupProfileMenu->insertSeparator();
     _backupProfileMenu->insertItem( i18n( "Delete Backup Profile" ), this, SLOT( fileDeleteBackupProfile() ) );
-    
+
     _fileMenu = new QPopupMenu;
     _fileMenu->insertItem( i18n( "Backup..." )            , this, SLOT( fileBackup() ) );
     _fileMenu->insertItem( i18n( "Restore..." )           , this, SLOT( fileRestore() ) );
@@ -143,7 +150,7 @@ KDat::KDat()
     _menu->insertItem( i18n( "&File" ), _fileMenu );
     _menu->insertItem( i18n( "&Edit" ), _editMenu );
     _menu->insertSeparator();
-    QString about = i18n( "KDat Version %1\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998 Sean Vyain\nsvyain@mail.tds.net" ).arg( KDAT_VERSION );
+    QString about = i18n( "KDat Version %1\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998-2000 Sean Vyain\nCopyright (c) 2001-2002 Lawrence Widman\nkdat@cardiothink.com" ).arg( KDAT_VERSION );
     _menu->insertItem( i18n( "&Help" ), helpMenu( about ) );
 
     _toolbar = new KToolBar( this );
@@ -169,25 +176,30 @@ KDat::KDat()
     _statusBar = new KStatusBar( this );
     _statusBar->insertItem( i18n( "Ready." ), 0 );
 
+#ifdef KDAT_HORIZONTAL_LAYOUT      /* 2002-01-20 LEW */
+    _panner = new QSplitter( QSplitter::Horizontal, this, "panner");
+#else
     _panner = new QSplitter( QSplitter::Vertical, this, "panner");
+#endif /* KDAT_HORIZONTAL_LAYOUT */
 
     // Create info viewers.
     InfoShellWidget* infoShell = new InfoShellWidget( _panner );
-    QVBoxLayout* infoLayout = new QVBoxLayout( _panner, 4, 4 );
-    infoLayout->addWidget( infoShell );
     _tapeInfo = new TapeInfoWidget( infoShell );
     _archiveInfo = new ArchiveInfoWidget( infoShell );
     _backupProfileInfo = new BackupProfileInfoWidget( infoShell );
     _tapeFileInfo = new TapeFileInfoWidget( infoShell );
     _fileInfo = new FileInfoWidget( infoShell );
 
+    // Now set up the tree
     _tree = new KTreeView( _panner );
-
     _tree->setExpandButtonDrawing( TRUE );
 
-    QVBoxLayout* localLayout = new QVBoxLayout( _panner, 4, 4 );
-
-    localLayout->addWidget( _tree, 1 );
+#ifdef KDAT_HORIZONTAL_LAYOUT      /* 2002-01-20 LEW */
+    _tree->setMinimumWidth( 300 );
+    _panner->moveToFirst( _tree );
+#else
+    _tree->setMinimumHeight( 300 );
+#endif /* KDAT_HORIZONTAL_LAYOUT */
 
     connect( _tree, SIGNAL( expanding( KTreeViewItem*, bool& ) ), this, SLOT( localExpanding( KTreeViewItem*, bool& ) ) );
     connect( _tree, SIGNAL( expanded( int ) ), this, SLOT( localExpanded( int ) ) );
@@ -356,11 +368,22 @@ void KDat::localCollapsed( int index )
 void KDat::localSelected( int index )
 {
     Node* item = (Node*)_tree->itemAt( index );
+
+    /* 2002-01-30 LEW: RG and I don't like the behavior in which
+       the subtree expands or contracts when a directory is selected
+       or unselected. 
+       so make the tree look the same when we are done....
+       The goal is to redraw the icon to the left of the item.
+       There's gotta be a better way to do this. */
     if ( item->isExpanded() ) {
-        _tree->collapseItem( index );
+      _tree->collapseItem( index );
+      _tree->expandItem( index );   // 2002-01-30 LEW
     } else {
-        _tree->expandItem( index );
+      _tree->expandItem( index );
+      _tree->collapseItem( index ); // 2002-01-30 LEW
     }
+    // repaint();  // this doesn't work   2002-01-30 LEW
+    /* 2002-01-30 LEW: RG and I don't like this behavior */
 }
 
 void KDat::localHighlighted( int index )
@@ -384,6 +407,29 @@ void KDat::fileBackup()
 {
     BackupProfile backupProfile;
 
+    /* 2002-01-28 LEW */
+    // To the i18n translator: I apologize for this long text on the last day to submit
+    // i18n changes.  But, the program isn't very usable without this information.  Thanks. LEW
+    // (later today):  now the program works correctly!  Why?  Beats me!
+    QString msg = i18n("KDat will dump your files properly to tape, but may not be able\n"
+                       "to restore them. To restore your files by hand, you need to know\n"
+                       "the name of the *non-rewinding* version of your tape device %1.\n"
+			).arg(Options::instance()->getTapeDevice());
+    QString msg2 = i18n("For example, if your device is /dev/st0, the non-rewinding version\n"
+                       "is /dev/nst0. If your device name doesn't look like that, type\n"
+                       "\"ls -l %2\" in a terminal window to see the real name of your\n"
+                       "tape drive. Substitute that name for /dev/nst0 below.\n"
+                       "Open a terminal window and type the following:\n"
+                       "  tar tfv /dev/nst0; tar tfv /dev/nst0\n"
+                       "  tar xfv /dev/nst0\n"
+                       "The third call to \"tar\" will retrieve your data into your\n"
+                       "current directory. Please let us know if this happens to you!\n"
+                       " - KDat Maintenance Team\n"
+			).arg(Options::instance()->getTapeDevice());
+    msg = msg.append(msg2);
+    KMessageBox::sorry( this, msg);
+    /* 2002-01-28 LEW */
+
     if ( ( _tree->getCurrentItem() ) && ( ((Node*)_tree->getCurrentItem())->isType( Node::BackupProfileNodeType ) ) ) {
         BackupProfile* bp = ((BackupProfileNode*)_tree->getCurrentItem())->getBackupProfile();
         backupProfile.setArchiveName( bp->getArchiveName() );
@@ -397,7 +443,7 @@ void KDat::fileBackup()
         QString name;
         name = i18n( "Archive created on %1" ).arg( KGlobal::locale()->formatDate(QDate::currentDate(), true) );
         name = name.stripWhiteSpace();
-        
+
         QStringList files;
         getBackupFiles( files );
 
@@ -416,9 +462,15 @@ void KDat::fileBackup()
         status( i18n( "Performing backup..." ) );
         int size = calcBackupSize( dlg.getWorkingDirectory(), dlg.isOneFilesystem(), dlg.getRelativeFiles(), dlg.isIncremental(), dlg.getSnapshotFile(), dlg.getRemoveSnapshot() );
 
+        // Check to see whether user aborted the backup
+        if ( size < 0) {
+	  status( i18n( "Backup canceled." ) );
+	  return;
+	}
+
         // Make sure the archive will fit on the tape.
         int tapeSize = 1;
-        QListIterator<Archive> i( TapeManager::instance()->getMountedTape()->getChildren() );
+        QPtrListIterator<Archive> i( TapeManager::instance()->getMountedTape()->getChildren() );
         if ( i.toLast() != NULL ) {
             tapeSize = i.current()->getEndBlock();
             tapeSize = (int)((float)tapeSize / 1024.0 * (float)Options::instance()->getTapeBlockSize()) + 1;
@@ -426,43 +478,45 @@ void KDat::fileBackup()
         if ( tapeSize + size >= TapeManager::instance()->getMountedTape()->getSize() ) {
             // Warn user that tape is probably too short.
             QString msg;
-            msg = i18n( "WARNING: The estimated archive size is %1 KB.\n"
-                        "The tape has only %2 KB of space!\n\n"
-                        "Backup anyway?" )
+            msg = i18n( "WARNING: The estimated archive size is %1 KB but "
+                        "the tape has only %2 KB of space!\n"
+                        "Back up anyway?" )
               .arg(KGlobal::locale()->formatNumber(size, 0))
               .arg(KGlobal::locale()->formatNumber(TapeManager::instance()->getMountedTape()->getSize() - tapeSize, 0 ));
-            if ( QMessageBox::warning( this, i18n( "KDat: Backup" ), 
-				       msg, i18n("Yes"), i18n("No") ) != 0 ) {
+            int result = KMessageBox::warningContinueCancel( this, 
+                               msg, i18n("Backup"), i18n("Backup") );
+            if ( result != KMessageBox::Continue) {
                 status( i18n( "Backup canceled." ) );
                 return;
             }
         }
-        
+
         if ( TapeDrive::instance()->getFile() < 0 ) {
             // Rewind tape.
             status( i18n( "Rewinding tape..." ) );
             if ( !TapeDrive::instance()->rewind() ) {
-                QMessageBox::warning( this, i18n( "KDat: Cannot Rewind Tape" ),
-				      i18n( "Cannot rewind tape.  Backup aborted." ), i18n("OK"));
+                KMessageBox::error( this, 
+                      i18n("Cannot rewind tape.\nBackup aborted."), 
+                      i18n("Backup Error"));
                 status( i18n( "Backup aborted." ) );
                 return;
             }
         }
-        
+
         // Go to end of tape.
         status( i18n( "Skipping to end of tape..." ) );
         if ( !TapeDrive::instance()->nextFile( TapeManager::instance()->getMountedTape()->getChildren().count() + 1 - TapeDrive::instance()->getFile() ) ) {
-            QMessageBox::warning( this, i18n( "KDat: Error" ), 
-				  i18n( "Cannot get to end of tape." ),
-				  i18n("OK"));
+            KMessageBox::error( this, 
+                      i18n("Cannot get to end of tape.\nBackup aborted."), 
+                      i18n("Backup Error"));
             status( i18n( "Backup aborted." ) );
             return;
         }
-        
+
         status( i18n( "Backup in progress..." ) );
         BackupDlg backupDlg( dlg.getArchiveName(), dlg.getWorkingDirectory(), dlg.getRelativeFiles(), dlg.isOneFilesystem(), dlg.isIncremental(), dlg.getSnapshotFile(), dlg.getRemoveSnapshot(), size, TapeManager::instance()->getMountedTape(), this );
         ret = backupDlg.exec();
-        
+
 //        status( i18n( "Rewinding tape..." ) );
 //        TapeDrive::instance()->rewind();
 //        if ( !TapeDrive::instance()->prevFile( 1 ) ) {
@@ -501,6 +555,17 @@ void KDat::doVerify( bool restore )
              ( ((SelectableNode*)_tapeDriveNode->childAt( i ))->hasSelectedChildren() )) {
             archiveNode = (MountedArchiveNode*)_tapeDriveNode->childAt( i );
             archive = archiveNode->getArchive();
+	    /* 2002-01-30 LEW */
+#ifdef DEBUG
+	    printf("KDat::doVerify: %d node of %s: ", i, 
+		   (SelectableNode*)_tapeDriveNode->getText().latin1() );
+            if( ((SelectableNode*)_tapeDriveNode->childAt( i ))->isSelected() ){
+	      printf("is completely selected\n");
+            } else {
+	      printf("is partially selected\n");
+            }
+#endif /* DEBUG */
+	    /* 2002-01-30 LEW */
             break;
         }
     }
@@ -516,7 +581,7 @@ void KDat::doVerify( bool restore )
     }
 
     assert( archive );
-    QListIterator<Archive> it( archive->getTape()->getChildren() );
+    QPtrListIterator<Archive> it( archive->getTape()->getChildren() );
     int fileno;
     for ( fileno = 1; ( it.current() ) && ( it.current() != archive ); ++it, fileno++ );
 
@@ -525,7 +590,7 @@ void KDat::doVerify( bool restore )
 
     RangeList ranges;
     if ( rangeableNode ) {
-        QListIterator<Range> it( rangeableNode->getRanges() );
+        QPtrListIterator<Range> it( rangeableNode->getRanges() );
         for ( ; it.current(); ++it ) {
             ranges.addRange( it.current()->getStart(), it.current()->getEnd() );
         }
@@ -555,7 +620,7 @@ void KDat::doVerify( bool restore )
         }
     } else {
         // Compile a list of files to verify/restore.
-        QStack<RangeableNode> stack;
+        QPtrStack<RangeableNode> stack;
 
         // Make sure the mounted archive node has populated its children.
         if ( archiveNode->childCount() == 0 ) {
@@ -570,7 +635,7 @@ void KDat::doVerify( bool restore )
         while ( stack.count() > 0 ) {
             sel = stack.pop();
             if ( sel->isSelected() ) {
-                QListIterator<Range> it( sel->getRanges() );
+                QPtrListIterator<Range> it( sel->getRanges() );
                 for ( ; it.current(); ++it ) {
                     ranges.addRange( it.current()->getStart(), it.current()->getEnd() );
                 }
@@ -600,7 +665,7 @@ void KDat::doVerify( bool restore )
         }
         VerifyDlg verifyDlg( dlg.getWorkingDirectory(), fileno, ranges, restore, this );
         int ret = verifyDlg.exec();
-        
+
         if ( ret == QDialog::Accepted ) {
             if ( restore ) {
                 status( i18n( "Restore complete." ) );
@@ -619,18 +684,28 @@ void KDat::doVerify( bool restore )
 
 void KDat::fileMountTape()
 {
+    static QString msg;
+
+    // construct helpful error message (same as in fileFormatTape())
+    msg = i18n("There appears to be no tape in the drive %1. Please\n"
+               "check \"Edit->Preferences\" to make sure the\n"
+               "correct device is selected as the tape drive (e.g.\n"
+               "/dev/st0). If you hear the tape drive moving, wait\n"
+               "until it stops and then try mounting it again.")
+                 .arg(Options::instance()->getTapeDevice());
+
     if ( !TapeManager::instance()->getMountedTape() ) {
         if ( Options::instance()->getLoadOnMount() ) {
             if ( !TapeDrive::instance()->load() ) {
-                QMessageBox::information( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), i18n("OK"));
+                KMessageBox::sorry( this, msg);
                 return;
             }
         }
-        
+
         if ( TapeDrive::instance()->isTapePresent() ) {
             setTapePresent( TRUE );
         } else {
-            QMessageBox::warning( this, i18n( "KDat: No Tape" ), i18n( "There is no tape in the drive." ), i18n("OK"));
+            KMessageBox::sorry( this, msg);
         }
     } else {
         setTapePresent( FALSE );
@@ -639,8 +714,10 @@ void KDat::fileMountTape()
 
 void KDat::fileIndexTape()
 {
-    if ( QMessageBox::warning( this, i18n( "KDat: Index Tape" ), 
-			       i18n( "The current tape index will be overwritten, continue?" ), i18n("Yes - Overwrite"), i18n("No") ) == 0 ) {
+    int result = KMessageBox::warningContinueCancel( this, 
+		       i18n( "The current tape index will be overwritten, continue?" ), 
+                       i18n( "Index Tape"), i18n("Overwrite"));
+    if ( result == KMessageBox::Continue) { 
         TapeManager::instance()->getMountedTape()->clear();
         IndexDlg dlg( TapeManager::instance()->getMountedTape(), this );
         if ( dlg.exec() == QDialog::Accepted ) {
@@ -660,7 +737,9 @@ void KDat::fileDeleteArchive()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::ArchiveNodeType ) && !sel->isType( Node::MountedArchiveNodeType ) ) ) {
-       QMessageBox::warning( this, i18n( "KDat: No Archive Selected" ), i18n( "An archive must be selected in the tree." ), i18n("OK"));
+        KMessageBox::sorry( this, i18n( "No archive is selected.\n"
+                                        "In order to delete an archive, the archive to be deleted "
+                                        "must be selected in the tree first." ));
         return;
     }
 
@@ -674,7 +753,7 @@ void KDat::fileDeleteArchive()
     assert( archive );
 
     Tape*    tape    = archive->getTape();
-    QListIterator<Archive> i( tape->getChildren() );
+    QPtrListIterator<Archive> i( tape->getChildren() );
     for ( ; i.current(); ++i ) {
         if ( i.current() == archive ) {
             break;
@@ -691,10 +770,11 @@ void KDat::fileDeleteArchive()
             list.append( i.current()->getName() );
         }
 
-        QString msg;
-        // msg.truncate( 32767 );
-        msg = i18n( "An archive cannot be removed from the middle of the tape. If\nthe archive '%1' is deleted then\nthe following archives will also be deleted:\n%2\n\nDelete all listed archives?" ).arg(archive->getName()).arg(list);
-        if ( QMessageBox::warning( this, i18n( "KDat: Delete Archives?" ), msg, i18n("Yes"), i18n("No") ) == 0 ) {
+        QString msg = 
+             i18n( "An archive cannot be removed from the middle of the tape. If\nthe archive '%1' is deleted then\nthe following archives will also be deleted:\n%2\n\nDelete all listed archives?" ).arg(archive->getName()).arg(list);
+        int result = KMessageBox::warningContinueCancel( this, 
+             msg, i18n("Delete Archive"), i18n("Delete All"));
+        if (result == KMessageBox::Continue) {
             tape->removeChild( archive );
             emit status( i18n( "Archives deleted." ) );
             if ( _tree->getCurrentItem() ) {
@@ -704,9 +784,11 @@ void KDat::fileDeleteArchive()
         }
     } else {
         // This is the last (known) archive on the tape.
-        QString msg;
-        msg = i18n( "Really delete the archive '%1'?" ).arg(archive->getName());
-        if ( QMessageBox::warning( this, i18n( "KDat: Delete Archive?" ), msg, i18n("Yes") ) == 0 ) {
+        QString msg = 
+             i18n( "Really delete the archive '%1'?" ).arg(archive->getName());
+        int result = KMessageBox::warningContinueCancel( this, 
+                              msg, i18n("Delete Archive"), i18n("Delete"));
+        if (result == KMessageBox::Continue) {
             tape->removeChild( archive );
             emit status( i18n( "Archive deleted." ) );
             if ( _tree->getCurrentItem() ) {
@@ -721,20 +803,26 @@ void KDat::fileDeleteIndex()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::TapeNodeType ) ) ) {
-        QMessageBox::warning( this, i18n( "KDat: No Tape Index Selected" ), i18n( "A tape index must be selected in the tree." ), i18n("OK") );
+        KMessageBox::sorry( this, i18n( "No tape index is selected.\n"
+                  "In order to delete a tape index, the tape index to be deleted "
+                  "must be selected in the tree first." ));
         return;
     }
 
     Tape* tape = ((TapeNode*)sel)->getTape();
     assert( tape );
     if ( tape == TapeManager::instance()->getMountedTape() ) {
-        QMessageBox::warning( this, i18n( "KDat: Tape Is Mounted" ), i18n( "The index for a mounted tape cannot be deleted.\n\nUnmount the tape and try again." ), i18n("OK") );
+        KMessageBox::sorry( this, i18n( "Tape is still mounted. "
+                  "The index for a mounted tape cannot be deleted.\n"
+                  "Unmount the tape and try again." ));
         return;
     }
 
-    QString msg;
-    msg = i18n( "Really delete the index for '%1'?" ).arg(tape->getName());
-    if ( QMessageBox::warning( this, i18n( "KDat: Delete Tape Index?" ), msg, i18n("OK") ) == 0 ) {
+    QString msg =
+         i18n( "Really delete the index for '%1'?" ).arg(tape->getName());
+    int result = KMessageBox::warningContinueCancel( this, 
+                    msg, i18n("Delete Tape Index"), i18n("Delete"));
+    if (result == KMessageBox::Continue) {
         TapeManager::instance()->removeTape( tape );
         emit status( i18n( "Tape index deleted." ) );
         if ( _tree->getCurrentItem() ) {
@@ -746,17 +834,31 @@ void KDat::fileDeleteIndex()
 
 void KDat::fileFormatTape()
 {
+    static QString msg;
+
+    // construct helpful error message (same as in fileMountTape())
+    msg = i18n("There appears to be no tape in the drive %1. Please\n"
+               "check \"Edit->Preferences\" to make sure the\n"
+               "correct device is selected as the tape drive (e.g.\n"
+               "/dev/st0). If you hear the tape drive moving, wait\n"
+               "until it stops and then try mounting it again.")
+                 .arg(Options::instance()->getTapeDevice());
+
     if ( !TapeDrive::instance()->isTapePresent() ) {
-        QMessageBox::warning( this, i18n( "KDat: No Tape In Drive" ), i18n( "There is no tape in the tape drive.\nPlease insert a tape and try again." ), i18n("OK") );
+        KMessageBox::sorry( this, msg );
         return;
     }
 
     if ( TapeDrive::instance()->isReadOnly() ) {
-        QMessageBox::warning( this, i18n( "KDat: Write Protected Tape" ), i18n( "The tape in the drive is write protected.\nPlease disable write protection and try again." ), i18n("OK") );
+        KMessageBox::sorry( this, i18n( "The tape in the drive is write protected.\nPlease disable write protection and try again." ));
         return;
     }
 
-    if ( KMessageBox::warningYesNo( this, i18n( "Format Tape" ), i18n( "All data will be lost, continue?" )) == 3 ) {
+    int result = KMessageBox::warningContinueCancel( this, 
+                     i18n( "All data currently on the tape will be lost.\n"
+                           "Are you sure you want to continue?" ), 
+                     i18n("Format Tape"), i18n("Format")); 
+    if (result == KMessageBox::Continue ) {
         QString name;
         name = i18n( "Tape created on %1" ).arg(  KGlobal::locale()->formatDate(QDate::currentDate(), true) );
         FormatOptDlg dlg( name.stripWhiteSpace(), this );
@@ -773,7 +875,7 @@ void KDat::fileFormatTape()
         Tape* tape = new Tape();
         tape->setName( dlg.getName() );
         tape->setSize( dlg.getSize() );
-        
+
         status( i18n( "Formatting tape..." ) );
         tape->format();
         TapeManager::instance()->addTape( tape );
@@ -807,7 +909,7 @@ void KDat::fileNewBackupProfile()
 
     QStringList files;
     getBackupFiles( files );
-    
+
     backupProfile->setName( name );
     backupProfile->setArchiveName( i18n( "Archive" ) );
     backupProfile->setWorkingDirectory( Util::longestCommonPath( files ) );
@@ -830,16 +932,19 @@ void KDat::fileDeleteBackupProfile()
 {
     Node* sel = (Node*)_tree->getCurrentItem();
     if ( ( !sel ) || ( !sel->isType( Node::BackupProfileNodeType ) ) ) {
-        QMessageBox::warning( this, i18n( "KDat: No Backup Profile Selected" ), i18n( "A backup profile must be selected in the tree." ), i18n("OK") );
+        KMessageBox::sorry( this, i18n( "In order to delete a backup profile, the backup profile to be deleted "
+                                        "must be selected in the tree first." ));
         return;
     }
 
     BackupProfile* backupProfile = ((BackupProfileNode*)sel)->getBackupProfile();
     assert( backupProfile );
 
-    QString msg;
-    msg = i18n("Really delete backup profile '%1'?").arg(backupProfile->getName());
-    if ( QMessageBox::warning( this, i18n( "KDat: Delete Backup Profile?" ), msg, i18n("Yes"), i18n("No") ) == 0 ) {
+    QString msg =
+         i18n("Really delete backup profile '%1'?").arg(backupProfile->getName());
+    int result = KMessageBox::warningContinueCancel( this, 
+                        msg, i18n("Delete backup profile"), i18n("Delete"));
+    if (result == KMessageBox::Continue) {
         BackupProfileManager::instance()->removeBackupProfile( backupProfile );
         emit status( i18n( "Backup profile deleted." ) );
         if ( _tree->getCurrentItem() ) {
@@ -890,9 +995,11 @@ void KDat::setTapePresent( bool tapePresent, bool eject )
                 TapeManager::instance()->mountTape( tape );
             } else {
                 if ( TapeDrive::instance()->isReadOnly() ) {
-                    QMessageBox::warning( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat." ), i18n("OK") );
+                    KMessageBox::sorry( this, i18n( "This tape has not been formatted by KDat." ));
                 } else {
-                    if ( QMessageBox::warning( this, i18n( "KDat: Unformatted Tape" ), i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ), i18n("Yes"), i18n("No") ) == 0 ) {
+                    int result = KMessageBox::questionYesNo( this, 
+                          i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ));
+                    if (result == KMessageBox::Yes) {
                         fileFormatTape();
                         return;
                     }
@@ -921,9 +1028,13 @@ void KDat::show()
     hideInfo();
 }
 
+// 2002-01-21 LEW: returns backup size in KB, or -1 if user chose
+// to abort the backup.
 int KDat::calcBackupSize( const QString& workingDir, bool local, const QStringList& files,
                           bool incremental, const QString& snapshot, bool removeSnapshot )
 {
+    int return_value;
+
     chdir( QFile::encodeName(workingDir) );
 
     bool useSnapshot = !snapshot.isEmpty() && !removeSnapshot;
@@ -943,6 +1054,12 @@ int KDat::calcBackupSize( const QString& workingDir, bool local, const QStringLi
 
     int size = 0;
 
+    /* 2002-01-24 LEW:  start of backup-cancel dialog */
+    create_backup_dialog();
+    stop_flag = FALSE;    // initialize the flag that tells us whether use
+                          // cancelled the backup via the dialog.
+    /* 2002-01-24 LEW:  end of backup-cancel dialog */
+
     QStringList filesTmp = files;
     QStringList::Iterator ii = filesTmp.begin();
     for ( ; ii != filesTmp.end(); ++ii ) {
@@ -959,7 +1076,7 @@ int KDat::calcBackupSize( const QString& workingDir, bool local, const QStringLi
             continue;
         }
 
-        QStack<QString> dirStack;
+        QPtrStack<QString> dirStack;
         dirStack.push( new QString( *ii ) );
 
         // If stay on one file system, get device of starting directory.
@@ -972,12 +1089,13 @@ int KDat::calcBackupSize( const QString& workingDir, bool local, const QStringLi
                 device = info.st_dev;
             }
         }
-        
+
         QString msg;
         // msg.truncate( 4095 );
         QDir dir;
         const QFileInfoList* infoList;
         while ( !dirStack.isEmpty() ) {
+	    if( stop_flag == TRUE ) break;
             QString* path = dirStack.pop();
             msg = i18n("Estimating backup size: %1, %2" )
              .arg(Util::kbytesToString( size / 2 ))
@@ -1014,8 +1132,14 @@ int KDat::calcBackupSize( const QString& workingDir, bool local, const QStringLi
         }
     }
 
+    delete _backupdialog;   // we're done, so zap this widget
+
     // Convert size in tar blocks to size in kbytes.
-    return size / 2;
+    return_value = size / 2;
+
+    if( stop_flag == TRUE ) return_value = -1;
+
+    return return_value;
 }
 
 void KDat::getBackupFiles( QStringList& files )
@@ -1027,7 +1151,7 @@ void KDat::getBackupFiles( QStringList& files )
         }
     } else {
         // Compile a list of files to backup.
-        QStack<ArchiveableNode> stack;
+        QPtrStack<ArchiveableNode> stack;
         stack.push( _rootNode );
         ArchiveableNode* sel = 0;
         while ( stack.count() > 0 ) {
@@ -1130,11 +1254,25 @@ void KDat::configureUI( Tape* tape )
         }
     }
     if ( canRestore ) {
-        for ( Node* parent = (Node*)sel->getParent(); ( parent ) && ( parent->getParent() ); parent = (Node*)parent->getParent() ) {
+      // 2002-01-30 LEW: check Node *sel because we can have canRestore==true 
+      // even if sel==NULL when a child is selected (see loop above).
+      if( sel != (Node *)0x0 )
+      { 
+        for ( Node* parent = (Node*)sel->getParent(); 
+              ( parent ) && ( parent->getParent() ); 
+              parent = (Node*)parent->getParent() ) {
             if ( parent->isType( Node::TapeNodeType ) ) {
                 canRestore = FALSE;
             }
         }
+      } 
+      // 2002-01-30 LEW: see if we ever get here...
+      else
+	{
+	printf("Found sel==0x0 in %s %d\n", __FILE__, __LINE__);
+	}
+      // 2002-01-30 LEW
+
     }
     _toolbar->setItemEnabled( 2, canRestore );
     _toolbar->setItemEnabled( 3, canRestore );
@@ -1177,3 +1315,62 @@ void KDat::saveProperties( KConfig* config )
 {
     config->writeEntry( "panner", _panner->sizes().first());
 }
+
+// Create the dialog that lets user cancel estimation of backup size
+void KDat::create_backup_dialog()
+{
+  /* 2002-01-24 LEW:  start of backup-cancel dialog */
+  static QString stop_button_text, stop_button_caption;
+  stop_button_text = 
+    i18n("Click \"CANCEL\" to stop the backup process.\n"
+	 "For example, you may quickly see that the size of\n"
+	 "the files you selected will exceed the size of the\n"
+	 "backup tape, and may then decide to stop and remove\n"
+	 "some files from your list of files to backup.\n\n"
+         "Click \"Continue\" to remove this message while\n"
+         "continuing the backup.");
+  stop_button_caption = i18n("Stop estimating backup size");
+
+        // gotta put a callback in here.  Probably need to create a
+        // dialog object  2002-01-22 LEW
+  _backupdialog = new KDialog( this, "backupdialog", false );
+  _backupdialog->setCaption( stop_button_caption );
+  //  _backupdialog->resize(370,200);  /* 2002-01-28 LEW */
+  _backupdialog->resize(370,260);
+
+  _lbl = new QLabel( stop_button_text, _backupdialog );
+  //  _lbl->setGeometry( QRect( 30, 20, 350, 140 ) );  /* 2002-01-28 LEW */
+  _lbl->setGeometry( QRect( 30, 20, 350, 200 ) ); 
+
+  _cancel = new QPushButton( i18n( "CANCEL" ), _backupdialog );
+  _cancel->setFixedSize( 80, _cancel->sizeHint().height() );
+  _cancel->setEnabled( TRUE );
+  /* 2002-01-24 LEW: looks like we can't increase the button width
+     to accomodate a wider message :( */
+  //  _cancel->setGeometry( QRect( 50, 170, 0, 0 ) );   /* 2002-01-28 LEW */
+  _cancel->setGeometry( QRect( 50, 230, 0, 0 ) ); 
+  connect( _cancel, SIGNAL( clicked() ), this, SLOT( backupCancel() ) );
+
+  _continue = new QPushButton( i18n( "Continue" ), _backupdialog );
+  _continue->setFixedSize( 80, _continue->sizeHint().height() );
+  _continue->setEnabled( TRUE );
+  _continue->setDefault( TRUE );
+  //  _continue->setGeometry( QRect( 200, 170, 0, 0 ) );   /* 2002-01-28 LEW */
+  _continue->setGeometry( QRect( 200, 230, 0, 0 ) ); 
+  connect( _continue, SIGNAL( clicked() ), this, SLOT( backupContinue() ) );
+
+  _backupdialog->show();
+}
+
+// stop calculating the backup size and hide the dialog screen
+void KDat::backupCancel()
+{
+  stop_flag = TRUE;
+  _backupdialog->hide();
+}
+
+// continue calculating the backup size and hide the dialog screen
+void KDat::backupContinue()
+{
+  _backupdialog->hide();
+}
