@@ -1,7 +1,8 @@
-// $Id: OptionsDlg.cpp,v 1.11 2000/10/25 23:02:28 rolandg Exp $
+// $Id: OptionsDlg.cpp,v 1.19 2002/01/20 19:56:13 widman Exp $
 //
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,13 +28,14 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 
 #include "Options.h"
 #include "OptionsDlg.h"
 #include <klocale.h>
+#include <kglobal.h>
 
 #include "OptionsDlg.moc"
 
@@ -198,7 +200,7 @@ void OptionsDlg::slotBrowseTarCommand()
     {
         if( !url.isLocalFile() )
         {
-            KMessageBox::sorry( 0L, i18n( "Only local files supported yet" ) );
+            KMessageBox::sorry( 0L, i18n( "Only local files are currently supported" ) );
             return;
         }
         _tarCommand->setText( url.path() );
