@@ -1,18 +1,18 @@
 /*
- * $Id: ktreeview.cpp,v 1.5 2000/10/24 23:00:58 coolo Exp $
+ * $Id: ktreeview.cpp,v 1.13 2002/01/31 07:09:36 widman Exp $
  *
  * KTreeView implementation
- * 
+ *
  * Copyright (C) 1997 Johannes Sixt
- * 
+ *
  * based on KTreeList, which is
  * Copyright (C) 1996 Keith Brown and KtSoft
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABLILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
@@ -28,13 +28,14 @@
 #include <qkeycode.h>			/* used for keyboard interface */
 #include <qpainter.h>			/* used to paint items */
 #include <qscrollbar.h>
+#include <qstyle.h>
 #include <assert.h>
 
 /*
  * -------------------------------------------------------------------
- * 
+ *
  * KTreeViewItem
- * 
+ *
  * -------------------------------------------------------------------
  */
 
@@ -257,8 +258,8 @@ void KTreeViewItem::insertChild(int index, KTreeViewItem* newChild)
     }
 }
 
-// indicates whether this item is displayed expanded 
-// NOTE: a TRUE response does not necessarily indicate the item 
+// indicates whether this item is displayed expanded
+// NOTE: a TRUE response does not necessarily indicate the item
 // has any children
 bool KTreeViewItem::isExpanded() const
 {
@@ -320,18 +321,18 @@ void KTreeViewItem::paintExpandButton(QPainter* p, int indent, int cellHeight) c
     p->setBrush(Qt::white);
     p->drawRect(expandButton);
     if (expanded) {
-	p->drawLine(parentLeaderX - 2, cellCenterY, 
+	p->drawLine(parentLeaderX - 2, cellCenterY,
 		    parentLeaderX + 2, cellCenterY);
     } else {
 	p->drawLine(parentLeaderX - 2, cellCenterY,
 		    parentLeaderX + 2, cellCenterY);
-	p->drawLine(parentLeaderX, cellCenterY - 2, 
+	p->drawLine(parentLeaderX, cellCenterY - 2,
 		    parentLeaderX, cellCenterY + 2);
     }
     p->setBrush(Qt::NoBrush);
 }
 
-// paint the highlight 
+// paint the highlight
 void KTreeViewItem::paintHighlight(QPainter* p, int indent, const QColorGroup& colorGroup,
 				   bool hasFocus, Qt::GUIStyle style) const
 {
@@ -367,11 +368,11 @@ void KTreeViewItem::paintText(QPainter* p, int indent, int cellHeight,
 			      const QColorGroup& cg, bool highlighted) const
 {
     int textX = indent + pixmap.width() + 4;
-    int textY = cellHeight - ((cellHeight - p->fontMetrics().ascent() - 
+    int textY = cellHeight - ((cellHeight - p->fontMetrics().ascent() -
 			       p->fontMetrics().leading()) / 2);
     if (highlighted) {
-	paintHighlight(p, indent, cg,
-		       owner->hasFocus(), owner->style().guiStyle());
+	paintHighlight(p, indent, cg, owner->hasFocus(),
+                       (Qt::GUIStyle)owner->style().styleHint(QStyle::SH_GUIStyle)); // Qt3 doesn't make this easy ;)
 	p->setPen(cg.base());
 	p->setBackgroundColor(cg.text());
     }
@@ -398,7 +399,7 @@ void KTreeViewItem::paintTree(QPainter* p, int indent, int cellHeight) const
 	p->drawLine(parentLeaderX, 0, parentLeaderX, cellCenterY);
 
     // draw the line down towards sibling
-    if (sibling) 
+    if (sibling)
 	p->drawLine(parentLeaderX, cellCenterY, parentLeaderX, cellBottomY);
 
     /*
@@ -575,7 +576,7 @@ int KTreeViewItem::width(int indent, const QFontMetrics& fm) const
 KTreeView::KTreeView(QWidget *parent,
 		     const char *name,
 		     WFlags f) :
-	QTableView(parent, name, f),
+	QGridView(parent, name, f),
 	clearing(false),
 	current(-1),
 	drawExpandButton(true),
@@ -588,23 +589,22 @@ KTreeView::KTreeView(QWidget *parent,
 	visibleItems(0),
 	rubberband_mode(false)
 {
-    initMetaObject();
     setCellHeight(0);
-    setCellWidth(0);
+//    setCellWidth(0);
     setNumRows(0);
     setNumCols(1);
-    setTableFlags(Tbl_autoScrollBars | Tbl_clipCellPainting | Tbl_snapToVGrid);
-    clearTableFlags(Tbl_scrollLastVCell | Tbl_scrollLastHCell | Tbl_snapToVGrid);
-    switch(style().guiStyle()) {
-    case WindowsStyle:
-    case MotifStyle:
+    setVScrollBarMode(Auto);
+    setHScrollBarMode(Auto);
+    //switch(style().guiStyle()) {
+    //case WindowsStyle:
+    //case MotifStyle:
 	setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
 	setBackgroundColor(colorGroup().base());
-	break;
-    default:
+	//break;
+    /*default:
 	setFrameStyle(QFrame::Panel | QFrame::Plain);
 	setLineWidth(1);
-    }
+    }*/
     // setAcceptFocus(true);
     treeRoot = new KTreeViewItem;
     treeRoot->setExpanded(true);
@@ -648,7 +648,7 @@ void KTreeView::appendChildItem(const QString & theText, const QPixmap& thePixma
 
 // appends the given item to the children of the item at the given index
 void KTreeView::appendChildItem(KTreeViewItem* newItem, int index)
-{                                                                  
+{
     /* find parent item and append new item to parent's sub tree */
     KTreeViewItem* parentItem = itemAt(index);
     if (!parentItem)
@@ -659,36 +659,36 @@ void KTreeView::appendChildItem(KTreeViewItem* newItem, int index)
 // appends the given item to the children of the item at the end of the
 // given path
 void KTreeView::appendChildItem(KTreeViewItem* newItem, const KPath& thePath)
-{                                
+{
     /* find parent item and append new item to parent's sub tree */
     KTreeViewItem* parentItem = itemAt(thePath);
     if (!parentItem)
 	return;
     appendChildItem(parentItem, newItem);
 }
-                                 
+
 // indicates whether horizontal scrollbar appears only when needed
 bool KTreeView::autoBottomScrollBar() const
 {
-  return testTableFlags(Tbl_autoHScrollBar);
+  return (hScrollBarMode() == Auto); 
 }
 
 // indicates whether vertical scrollbar appears only when needed
 bool KTreeView::autoScrollBar() const
 {
-  return testTableFlags(Tbl_autoVScrollBar);
+  return (vScrollBarMode() == Auto);
 }
 
 // indicates whether display updates automatically on changes
 bool KTreeView::autoUpdate() const
 {
-  return QTableView::autoUpdate();
+  return isUpdatesEnabled();
 }
 
 // indicates whether horizontal scrollbar is present
 bool KTreeView::bottomScrollBar() const
 {
-  return testTableFlags(Tbl_hScrollBar);
+  return !(horizontalScrollBar()->isHidden());
 }
 
 // find item at specified index and change pixmap and/or text
@@ -716,14 +716,14 @@ void KTreeView::changeItem(const QString & newText,
 // clear all items from list and erase display
 void KTreeView::clear()
 {
-    setCurrentItem(-1);	
+    setCurrentItem(-1);
 
     /* somewhat of a hack for takeItem so it doesn't update the current item... */
 	clearing = TRUE;
-	
+
 	bool autoU = autoUpdate();
 	setAutoUpdate(FALSE);
-	QStack<KTreeViewItem> stack;
+	QPtrStack<KTreeViewItem> stack;
 	stack.push(treeRoot);
 	while(!stack.isEmpty()) {
 		KTreeViewItem *item = stack.pop();
@@ -797,7 +797,7 @@ void KTreeView::expandOrCollapseItem(int index)
     expandOrCollapse(item);
 }
 
-// visits every item in the tree, visible or not and applies 
+// visits every item in the tree, visible or not and applies
 // the user supplied function with the item and user data passed as parameters
 // if user supplied function returns true, traversal ends and function returns
 bool KTreeView::forEveryItem(KForEvery func, void* user, KTreeViewItem* item)
@@ -823,7 +823,7 @@ bool KTreeView::forEveryItem(KForEvery func, void* user, KTreeViewItem* item)
     return false;
 }
 
-// visits every visible item in the tree in order and applies the 
+// visits every visible item in the tree in order and applies the
 // user supplied function with the item and user data passed as parameters
 // if user supplied function returns TRUE, traversal ends and function
 // returns
@@ -925,7 +925,7 @@ bool KTreeView::insertItem(KTreeViewItem* newItem,
 // of prefix
 bool KTreeView::insertItem(KTreeViewItem* newItem,
 			   const KPath& thePath, bool prefix)
-{                              
+{
     // find the item currently at the end of the path, if there is one
     KTreeViewItem* refItem = itemAt(thePath);
 
@@ -1050,7 +1050,7 @@ void KTreeView::raiseItem(const KPath& path)
 void KTreeView::removeItem(int index)
 {
   KTreeViewItem *item = itemAt(index);
-  if(item) { 
+  if(item) {
     takeItem(item);
     delete item;
   }
@@ -1069,20 +1069,19 @@ void KTreeView::removeItem(const KPath& thePath)
 // indicates whether vertical scrollbar is present
 bool KTreeView::scrollBar() const
 {
-  return testTableFlags(Tbl_vScrollBar);
+  return !(verticalScrollBar()->isHidden());
 }
 
 // enables/disables auto update of display
 void KTreeView::setAutoUpdate(bool enable)
 {
-  QTableView::setAutoUpdate(enable);
+  setUpdatesEnabled(enable);
 }
 
 // enables/disables horizontal scrollbar
 void KTreeView::setBottomScrollBar(bool enable)
 {
-  enable ? setTableFlags(Tbl_hScrollBar) :
-    clearTableFlags(Tbl_hScrollBar);
+  setHScrollBarMode(enable ? AlwaysOn : AlwaysOff);
 }
 
 // sets the current item and hightlights it, emitting signals
@@ -1100,7 +1099,7 @@ void KTreeView::setCurrentItem(int row)
     if (oldCurrent < numVisible)
 	updateCell(oldCurrent, 0);
     if (current > -1) {
-	updateCell(current, 0, false);
+	updateCell(current, 0);
     }
 
     emit highlighted( current );
@@ -1150,8 +1149,7 @@ void KTreeView::setIndentSpacing(int spacing)
 // enables/disables vertical scrollbar
 void KTreeView::setScrollBar(bool enable)
 {
-  enable ? setTableFlags(Tbl_vScrollBar) :
-    clearTableFlags(Tbl_vScrollBar);
+  setVScrollBarMode(enable? AlwaysOn : AlwaysOff );
 }
 
 // enables/disables display of item text (keys)
@@ -1168,8 +1166,7 @@ void KTreeView::setShowItemText(bool enable)
 // indicates whether vertical scrolling is by pixel or row
 void KTreeView::setSmoothScrolling(bool enable)
 {
-  enable ? setTableFlags(Tbl_smoothVScrolling) :
-    clearTableFlags(Tbl_smoothVScrolling);
+  verticalScrollBar()->setLineStep(enable ? 1 : cellHeight());
 }
 
 // enables/disables tree branch drawing
@@ -1182,7 +1179,7 @@ void KTreeView::setTreeDrawing(bool enable)
   if(autoUpdate() && isVisible())
     repaint();
 }
-    
+
 // indicates whether item text keys are displayed
 bool KTreeView::showItemText() const
 {
@@ -1192,7 +1189,7 @@ bool KTreeView::showItemText() const
 // indicates whether scrolling is by pixel or row
 bool KTreeView::smoothScrolling() const
 {
-  return testTableFlags(Tbl_smoothVScrolling);
+  return (verticalScrollBar()->lineStep() == 1);
 }
 
 // indents the item at the given index, splitting the tree into
@@ -1270,23 +1267,6 @@ void KTreeView::appendChildItem(KTreeViewItem* theParent,
     }
 }
 
-// returns the height of the cell(row) at the specified row (index)
-int KTreeView::cellHeight(int row)
-{
-    if ( itemAt( row ) ) {
-        return itemAt(row)->height(fontMetrics());
-    } else {
-        return 0;
-    }
-}
-
-// returns the width of the cells. Note: this is mostly for derived classes
-// which have more than 1 column
-int KTreeView::cellWidth(int /*col*/)
-{
-  return maxItemWidth;
-}
-
 // changes the given item with the new text and/or pixmap
 void KTreeView::changeItem(KTreeViewItem* toChange, int itemRow,
 			   const QString & newText, const QPixmap* newPixmap)
@@ -1301,7 +1281,7 @@ void KTreeView::changeItem(KTreeViewItem* toChange, int itemRow,
 	updateCellWidth();
     if(itemRow == -1)
 	return;
-    if(autoUpdate() && rowIsVisible(itemRow))
+    if(autoUpdate())
 	updateCell(itemRow, 0);
 }
 
@@ -1342,7 +1322,7 @@ void KTreeView::expandOrCollapse(KTreeViewItem* parent)
     bool autoU = autoUpdate();
     setAutoUpdate(false);
     int parentIndex = itemRow(parent);
-    if (parent->isExpanded()) { 
+    if (parent->isExpanded()) {
 	collapseSubTree(parent);
     emit collapsed(parentIndex);
     }
@@ -1384,7 +1364,7 @@ void KTreeView::expandSubTree(KTreeViewItem* subRoot)
     repaint();
     setAutoUpdate(TRUE);
     // roland
-    
+
 }
 
 // fix up branch levels out of whack from split/join operations on the tree
@@ -1394,7 +1374,7 @@ void KTreeView::fixChildren(KTreeViewItem *parentItem)
     KTreeViewItem* siblingItem = 0;
 //    int childBranch = parentItem->getBranch() + 1;
     if(parentItem->hasChild()) {
-	childItem = parentItem->getChild(); 
+	childItem = parentItem->getChild();
 //	childItem->setBranch(childBranch);
 	childItem->owner = parentItem->owner;
 	fixChildren(childItem);
@@ -1405,7 +1385,7 @@ void KTreeView::fixChildren(KTreeViewItem *parentItem)
 	siblingItem->owner = parentItem->owner;
 	fixChildren(siblingItem);
 	childItem = siblingItem;
-    }	
+    }
 }
 
 // handles QFocusEvent processing by setting current item to top
@@ -1414,11 +1394,11 @@ void KTreeView::fixChildren(KTreeViewItem *parentItem)
 void KTreeView::focusInEvent(QFocusEvent *)
 {
   if(current < 0 && numRows() > 0)
-    setCurrentItem(topCell());
+    setCurrentItem(rowAt(contentsY()));
   updateCell(current, 0);
 }
 
-// visits every item in the tree, visible or not and applies the user 
+// visits every item in the tree, visible or not and applies the user
 // supplied member function with the item and user data passed as parameters
 // if the user supplied member function returns TRUE, traversal
 // ends and the function returns
@@ -1426,7 +1406,7 @@ void KTreeView::forEveryItem(KForEveryM func,
 			   void *user)
 {
   KTreeViewItem *item = treeRoot->getChild();
-  QStack<KTreeViewItem> stack;
+  QPtrStack<KTreeViewItem> stack;
   while(item) {
     stack.push(item);
     while(!stack.isEmpty()) {
@@ -1445,14 +1425,14 @@ void KTreeView::forEveryItem(KForEveryM func,
   }
 }
 
-// visits every visible item in the tree in order and applies the user 
+// visits every visible item in the tree in order and applies the user
 // supplied member function with the item and user data passed as parameters
 // if user supplied function returns TRUE, traversal ends and function
 // returns
 void KTreeView::forEveryVisibleItem(KForEveryM func,
 				       void *user)
 {
-  QStack<KTreeViewItem> stack;
+  QPtrStack<KTreeViewItem> stack;
   KTreeViewItem *item = treeRoot->getChild();
   do {
     while(item) {
@@ -1499,9 +1479,13 @@ bool KTreeView::insertItem(KTreeViewItem* referenceItem,
     newItem->setDrawExpandButton(drawExpandButton);
     newItem->setDrawTree(drawTree);
     newItem->setDrawText(showText);
+    if (cellHeight() == 0)
+    {
+       setCellHeight(newItem->height(fontMetrics()));
+    }
     KTreeViewItem* parentItem;
     if (referenceItem) {
-	parentItem = referenceItem->getParent(); 
+	parentItem = referenceItem->getParent();
 	int insertIndex = parentItem->childIndex(referenceItem);
 	if (!prefix)
 	    insertIndex++;
@@ -1569,16 +1553,16 @@ void KTreeView::join(KTreeViewItem *item)
 // handles keyboard interface to tree list
 void KTreeView::keyPressEvent(QKeyEvent *e)
 {
-  if(numRows() == 0) 
-    
+  if(numRows() == 0)
+
     // nothing to be done
-    
+
     return;
   if(currentItem() < 0)
-    
+
     // if no current item, make the top item current
-  
-    setCurrentItem(topCell()); 
+
+    setCurrentItem(rowAt(contentsY()));
   int pageSize, delta;
   switch(e->key()) {
     case Key_Up:
@@ -1587,57 +1571,53 @@ void KTreeView::keyPressEvent(QKeyEvent *e)
 
       if(currentItem() > 0) {
 	setCurrentItem(currentItem() - 1);
-	if(currentItem() < topCell())
-	  setTopCell(currentItem());
+        ensureCellVisible(currentItem(), 0);
       }
       break;
     case Key_Down:
-    
+
       // make next item current, scroll down if necessary
-      
+
       if (currentItem() < numRows() - 1) {
 	setCurrentItem(currentItem() + 1);
-	if(currentItem() > lastRowVisible())
-	  setTopCell(topCell() + currentItem() - lastRowVisible());
+        ensureCellVisible(currentItem(), 0);
       }
       break;
     case Key_Next:
-    
+
       // move highlight one page down and scroll down
-       
-      delta = currentItem() - topCell();
-      pageSize = lastRowVisible() - topCell();
-      setTopCell(QMIN(topCell() +  pageSize, numRows() - 1));
-      setCurrentItem(QMIN(topCell() + delta, numRows() - 1));
+
+      delta = QMAX(1, visibleHeight() / cellHeight());
+      setCurrentItem(QMIN(currentItem() + delta, numRows() - 1));
+      ensureCellVisible(currentItem(), 0);
       break;
     case Key_Prior:
-    
+
       // move highlight one page up and scroll up
-      
-      delta = currentItem() - topCell();
-      pageSize = lastRowVisible() - topCell();
-      setTopCell(QMAX(topCell() - pageSize, 0));
-      setCurrentItem(QMAX(topCell() + delta, 0));
+
+      delta = QMAX(1, visibleHeight() / cellHeight());
+      setCurrentItem(QMAX(currentItem() - delta, 0));
+      ensureCellVisible(currentItem(), 0);
       break;
     case Key_Plus:
-    
+
       // if current item has subtree and is collapsed, expand it
-      
+
       if(currentItem() >= 0)
 	expandItem(currentItem());
       break;
     case Key_Minus:
-    
+
       // if current item has subtree and is expanded, collapse it
-      
+
       if(currentItem() >= 0)
 	collapseItem(currentItem());
       break;
     case Key_Return:
     case Key_Enter:
-    
+
       // select the current item
-      
+
       if(currentItem() >= 0)
 	emit selected(currentItem());
       break;
@@ -1681,28 +1661,26 @@ void KTreeView::lowerItem(KTreeViewItem *item)
 void KTreeView::mouseDoubleClickEvent(QMouseEvent *e)
 {
   // find out which row has been clicked
-	
-  QPoint mouseCoord = e->pos();
-  int itemClicked = findRow(mouseCoord.y());
-  
+
+  QPoint mouseCoord = viewportToContents(e->pos());
+  int itemClicked = rowAt(mouseCoord.y());
+
   // if a valid row was not clicked, do nothing
-  
-  if(itemClicked == -1) 
+
+  if(itemClicked == -1)
     return;
 
   KTreeViewItem *item = itemAt(itemClicked);
   if(!item) return;
-  
-  // translate mouse coord to cell coord
-  
-  int  cellX, cellY;
-  colXPos(0, &cellX);
-  rowYPos(itemClicked, &cellY);
-  QPoint cellCoord(mouseCoord.x() - cellX, mouseCoord.y() - cellY);
-  
-  // hit test item
 
-    int indent = indentation(item);
+  // translate mouse coord to cell coord
+
+  int cellY = cellHeight()*itemClicked;
+  int cellX = 0;
+  QPoint cellCoord(mouseCoord.x() - cellX, mouseCoord.y() - cellY);
+
+  // hit test item
+  int indent = indentation(item);
   if(item->boundingRect(indent).contains(cellCoord))
     emit selected(itemClicked);
 }
@@ -1711,7 +1689,7 @@ void KTreeView::mouseDoubleClickEvent(QMouseEvent *e)
 void KTreeView::mouseMoveEvent(QMouseEvent *e)
 {
   // in rubberband_mode we actually scroll the window now
-  if (rubberband_mode) 
+  if (rubberband_mode)
 	{
 	  move_rubberband(e->pos());
 	}
@@ -1723,14 +1701,14 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 {
     // first: check which button was pressed
 
-    if (e->button() == MidButton) 
+    if (e->button() == MidButton)
     {
 	// RB: the MMB is hardcoded to the "rubberband" scroll mode
 	if (!rubberband_mode) {
 	    start_rubberband(e->pos());
 	}
 	return;
-    } 
+    }
     else if ( ( rubberband_mode ) && ( e->button() != RightButton ) )
     {
 	// another button was pressed while rubberbanding, stop the move.
@@ -1742,10 +1720,10 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
     }
 
     // find out which row has been clicked
-    QPoint mouseCoord = e->pos();
-    int itemClicked = findRow(mouseCoord.y());
+    QPoint mouseCoord = viewportToContents(e->pos());
+    int itemClicked = rowAt(mouseCoord.y());
 
-    // nothing to do if not on valid row  
+    // nothing to do if not on valid row
     if (itemClicked == -1)
 	return;
 
@@ -1754,22 +1732,25 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 	return;
 
     // translate mouse coord to cell coord
-    int  cellX, cellY;
-    colXPos(0, &cellX);
-    rowYPos(itemClicked, &cellY);
+    int  cellX = 0;
+    int  cellY = cellHeight()*itemClicked;
     QPoint cellCoord(mouseCoord.x() - cellX, mouseCoord.y() - cellY);
 
-    /* hit test expand button (doesn't set currentItem) */
+    /* hit expand button (doesn't set currentItem) */
     if(item->expandButtonClicked(cellCoord)) {
 	expandOrCollapse(item);
     }
-    // hit tets select button
+    // hit select button (to select/deselect the item for backup)
+    // 2002-01-20 LEW: I'm adding the emit() here so that the screen gets updated,
+    // as in KTreeView::mouseDoubleClickEvent().  KTreeViewItem::mousePressEvent()
+    // returns false, so I guess some other function is being called here.
     else if ( item->mousePressEvent( cellCoord ) ) {
-        // Item processed the button press.
+        // Item processed the button press in localSelected(itemClicked)
+        emit selected(itemClicked);
     }
-    // hit test item
+    // hit item (to show info on the file/dir label clicked)
     else if (item->boundingRect(indentation(item)).contains(cellCoord)) {
-	setCurrentItem(itemClicked);
+      setCurrentItem(itemClicked);   // highlight item
         if ( e->button() == RightButton ) {
             emit popupMenu( itemClicked, mapToGlobal( QPoint( e->pos().x(), e->pos().y() ) ) );
         }
@@ -1780,7 +1761,7 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 void KTreeView::mouseReleaseEvent(QMouseEvent *e)
 {
   /* if it's the MMB end rubberbanding */
-  if (rubberband_mode && e->button()==MidButton) 
+  if (rubberband_mode && e->button()==MidButton)
 	{
 	  end_rubberband();
 	}
@@ -1789,6 +1770,7 @@ void KTreeView::mouseReleaseEvent(QMouseEvent *e)
 // rubberband move: draw the rubberband
 void KTreeView::draw_rubberband()
 {
+#if 0
     /*
      * RB: I'm using a white pen because of the XorROP mode. I would prefer
      * to draw the rectangle in red but I don't now how to get a pen which
@@ -1804,16 +1786,18 @@ void KTreeView::draw_rubberband()
                  yOffset()*viewHeight()/totalHeight(),
                  rubber_width+1, rubber_height+1);
   paint.end();
+#endif
 }
 
 // rubberband move: start move
 void KTreeView::start_rubberband(const QPoint& where)
 {
+#if 0
   if (rubberband_mode) { // Oops!
     end_rubberband();
   }
     /* RB: Don't now, if this check is necessary */
-  if (!viewWidth() || !viewHeight()) return; 
+  if (!viewWidth() || !viewHeight()) return;
   if (!totalWidth() || !totalHeight()) return;
 
   // calculate the size of the rubberband rectangle
@@ -1828,19 +1812,23 @@ void KTreeView::start_rubberband(const QPoint& where)
   rubber_startY = yOffset();
   rubberband_mode=TRUE;
   draw_rubberband();
+#endif
 }
 
 // rubberband move: end move
 void KTreeView::end_rubberband()
 {
+#if 0
   if (!rubberband_mode) return;
   draw_rubberband();
   rubberband_mode = FALSE;
+#endif
 }
 
-// rubberband move: hanlde mouse moves
+// rubberband move: handle mouse moves
 void KTreeView::move_rubberband(const QPoint& where)
 {
+#if 0
   if (!rubberband_mode) return;
 
   // look how much the mouse moved and calc the new scroll position
@@ -1858,6 +1846,7 @@ void KTreeView::move_rubberband(const QPoint& where)
   draw_rubberband();
   setOffset(nx,ny);
   draw_rubberband();
+#endif
 }
 
 
@@ -1869,10 +1858,12 @@ void KTreeView::paintCell(QPainter* p, int row, int)
     if (item == 0)
 	return;
 
+    p->setClipRect(cellRect(), QPainter::CoordPainter );
     QColorGroup cg = colorGroup();
     int indent = indentation(item);
     item->paint(p, indent, cg,
 		current == row);		/* highlighted */
+    p->setClipping(false);
 }
 
 /* raise the specified item up one slot in parent's subtree */
@@ -1945,7 +1936,7 @@ bool KTreeView::setItemExpandButtonDrawing(KTreeViewItem *item,
 }
 
 // called by setShowItemText for every item in tree
-bool KTreeView::setItemShowText(KTreeViewItem *item, 
+bool KTreeView::setItemShowText(KTreeViewItem *item,
 				   void *)
 {
   item->setDrawText(showText);
@@ -2020,23 +2011,16 @@ void KTreeView::takeItem(KTreeViewItem* item)
     setCurrentItem(cur != 0  ?  itemRow(cur)  :  -1);
 }
 
-// visits each item, calculates the maximum width  
-// and updates QTableView
+// visits each item, calculates the maximum width
+// and updates QGridView
 void KTreeView::updateCellWidth()
 {
     // make cells at least 1 pixel wide to avoid singularities (division by zero)
     int maxW = 1;
     forEveryVisibleItem(&KTreeView::getMaxItemWidth, &maxW);
     maxItemWidth = maxW;
-    updateTableSize();
-
-    int xoff = xOffset();
-    int yoff = yOffset();
-
-    if ( xoff > maxXOffset() ) xoff = maxXOffset();
-    if ( yoff > maxYOffset() ) yoff = maxYOffset();
-
-    setOffset( xoff, yoff );
+    setCellWidth(maxW);
+    update();
 }
 
 void KTreeView::updateVisibleItems()
