@@ -64,6 +64,10 @@
 #include <config.h>
 #endif
 
+#ifdef __sgi__
+#define __svr4__
+#endif
+
 #if defined(HAVE_GRANTPT) && defined(HAVE_PTSNAME) && defined(HAVE_UNLOCKPT) && !defined(_XOPEN_SOURCE) && !defined(__svr4__)
 #define _XOPEN_SOURCE // make stdlib.h offer the above fcts
 #endif
@@ -145,10 +149,6 @@ extern "C" {
 #include <bsdtty.h>
 #endif
 
-#ifdef __sgi__
-#define __svr4__
-#endif
-
 #include <qintdict.h>
 #include <qstring.h>
 #include <sys/wait.h>
@@ -158,9 +158,9 @@ extern "C" {
 #include "TEPty.moc"
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
 #ifndef HERE
@@ -247,7 +247,11 @@ void TEPty::donePty()
   }
 #endif
   if (needGrantPty) chownpty(fd,FALSE);
+  kdDebug() << "CLOSE........................\n";
+  close(fd);
   emit done(status);
+
+  fd = openPty();
 }
 
 
@@ -261,8 +265,13 @@ const char* TEPty::deviceName()
 */
 int TEPty::run(const char* _pgm, QStrList & _args, const char* _term, int _addutmp)
 {
-  arguments = _args;
+  clearArguments();
+
+  QStrListIterator it( _args );
+  for (; it.current(); ++it )
+    arguments << it.current();
   arguments.prepend(_pgm);
+
   term = _term;
   addutmp = _addutmp;
 
@@ -405,7 +414,7 @@ int TEPty::openPty()
 }
 
 //! only used internally. See `run' for interface
-void TEPty::makePty(const char* dev, const char* pgm, QStrList & args, const char* term, int )
+void TEPty::makePty(const char* dev, const char* pgm, QValueList<QCString> & args, const char* term, int )
 { 
   int sig;
   if (fd < 0) // no master pty could be opened
@@ -560,7 +569,7 @@ void TEPty::makePty(const char* dev, const char* pgm, QStrList & args, const cha
   // convert QStrList into char*[]
   unsigned int i;
   char **argv = (char**)malloc(sizeof(char*)*(args.count()+1));
-  for (i = 0; i<args.count(); i++) argv[i] = strdup(args.at(i));
+  for (i = 0; i<args.count(); i++) argv[i] = strdup(args[i]);
   argv[i] = 0L;
 
   ioctl(0,TIOCSWINSZ,(char *)&wsize);  // set screen size
@@ -607,7 +616,8 @@ int TEPty::setupCommunication(Communication comm)
 int TEPty::commSetupDoneC()
 {
   //  kdDebug() << fd << "commSetupDoneC\n";
-   const char *pgm = arguments.take(0);
+   QCString pgm = arguments.first();
+   arguments.pop_front();
    makePty(ttynam, pgm,arguments,term,addutmp);
    return 0; // Never reached.
 }
@@ -615,7 +625,7 @@ int TEPty::commSetupDoneC()
 /*! sends a character through the line */
 void TEPty::send_byte(char c)
 {
-  //    kdDebug() << fd << c << "send_byte\n";
+  //  kdDebug() << fd << ":" << c << "send_byte\n";
   write(fd,&c,1);
 }
 
