@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debAptInterface.h,v 1.9 2001/01/14 16:44:21 toivo Exp $ 
+//      $Id: debAptInterface.h,v 1.12 2002/01/27 06:30:43 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -19,21 +19,20 @@ class DEBAPT: public DEB
   Q_OBJECT
 
 public:
-  DEBAPT(QString remote);
+  DEBAPT();
   ~DEBAPT();
 
-  void setRemote(QString remote);
-  // set remote access if requested
+  virtual bool isType(char *buf, const QString &fname);
 
-  void listPackages(QList<packageInfo> *pki);
+  void listPackages(QPtrList<packageInfo> *pki);
   QStringList listInstalls(QStringList packs, bool install);
 
   QString doUninstall(int uninstallFlags, QString packs, bool &test);
   QString doInstall(int installFlags, QString packs, bool &test);
-  QString install(int installFlags, QList<packageInfo> *p,
+  QString install(int installFlags, QPtrList<packageInfo> *p,
 		  bool &test);
 
-  void listRemotePackages(QList<packageInfo> *pki);
+  void listRemotePackages(QPtrList<packageInfo> *pki);
   QStringList getFileList(packageInfo *p);
 
   KAction *updateM, *upgradeM, *fixupM;
@@ -47,8 +46,8 @@ private slots:
   void fixupS();
 
 private:
-  void listAvail(QList<packageInfo> *pki);
-  void listRPack(QList<packageInfo> *pki);
+  void listAvail(QPtrList<packageInfo> *pki);
+  void listRPack(QPtrList<packageInfo> *pki);
   QStringList getRFileList(packageInfo *p);
 
 };
