@@ -1,5 +1,5 @@
-//////////////////////////////////////////////////////////////         
-//      $Id: debInterface.cpp,v 1.45 2001/01/22 15:43:05 toivo Exp $ 
+//////////////////////////////////////////////////////////////
+//      $Id: debInterface.cpp,v 1.55 2002/01/27 06:30:43 toivo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -12,7 +12,7 @@
 #include <fcntl.h>		// for O_RDONLY
 #include <time.h>		// for localtime
 #include <setjmp.h>
-#include <iostream.h>   
+#include <iostream.h>
 
 #include <kurl.h>
 #include <kglobal.h>
@@ -24,20 +24,18 @@
 #include "kpackage.h"
 #include "managementWidget.h"
 #include "utils.h"
-#include "procbuf.h"
 #include "options.h"
 #include "cache.h"
 #include <klocale.h>
 
-
 extern KApplication *app;
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-DEB::DEB(QString remote):pkgInterface(remote)
+DEB::DEB():pkgInterface()
 {
   head = "DEB";
-  icon = "deb";  
+  icon = "deb";
 
   pict = UserIcon(icon);
   bad_pict = UserIcon("dbad");
@@ -69,12 +67,12 @@ bool DEB::isType(char *buf, const QString &)
     return false;
 }
 
-void DEB::distPackages(QList<packageInfo> *, cacheObj *)
-{ 
+void DEB::distPackages(QPtrList<packageInfo> *, cacheObj *)
+{
 }
 
-void DEB::listUnIPackages(QList<packageInfo> *pki, LcacheObj *pCache)
-{ 
+void DEB::listUnIPackages(QPtrList<packageInfo> *pki, LcacheObj *pCache)
+{
   QString s;
   cacheObj *cp;
 
@@ -86,7 +84,7 @@ void DEB::listUnIPackages(QList<packageInfo> *pki, LcacheObj *pCache)
       if (!s.isEmpty()) {
 	listPackList(pki,s,cp);
       }
-    } else { 
+    } else {
       s = getDir(cp);
       if (!s.isEmpty()) {
 	listDir(pki,s,cp->location);
@@ -114,12 +112,12 @@ bool DEB::parseName(QString name, QString *n, QString *v)
   return FALSE;
 }
 
-void DEB::listInstalledPackages(QList<packageInfo> *pki)
+void DEB::listInstalledPackages(QPtrList<packageInfo> *pki)
 {
   listPackList(pki,STATUS,0);
 }
 
-void DEB::listPackList(QList<packageInfo> *pki, const QString &fname, cacheObj *cp)
+void DEB::listPackList(QPtrList<packageInfo> *pki, const QString &fname, cacheObj *cp)
 {
   bool local = FALSE;
   packageInfo *p;
@@ -148,7 +146,7 @@ void DEB::listPackList(QList<packageInfo> *pki, const QString &fname, cacheObj *
       } else {
 	p = collectInfo(list);
 	if (p) {
-	  if (!p->update(pki, typeID, cp == 0)) {
+	  if (!p->pkgInsert(pki, typeID, cp == 0)) {
 	    delete p;
 	  } else if (cp) {
 	    p->info->insert("base",new QString(cp->base));
@@ -168,23 +166,27 @@ void DEB::listPackList(QList<packageInfo> *pki, const QString &fname, cacheObj *
 //////////////////////////////////////////////////////////////////////////////
 packageInfo *DEB::getPackageInfo(char mode, const QString &name, const QString &)
 {
-  if (mode == 'i')
-    return getIPackageInfo(name);
-  else
+  if (mode == 'i') {
+    if (hostName.isEmpty()) {
+      return getIPackageInfo(name);
+    } else {
+      return getIRPackageInfo(name);
+    }
+  } else
     return getUPackageInfo(name);
 }
 
 packageInfo *DEB::getIPackageInfo( const QString &name)
 {
   // query an installed package!
-  packageInfo *pki = 0; 
+  packageInfo *pki = 0;
   QString search;
   QStringList list;
-  
+
   search = "Package: "+ name;
 
   QFile f(STATUS);
-  if ( f.open(IO_ReadOnly) ) {  
+  if ( f.open(IO_ReadOnly) ) {
     QTextStream t( &f );
     QString s;
     while ( !t.eof() ) {
@@ -202,7 +204,7 @@ packageInfo *DEB::getIPackageInfo( const QString &name)
 	list << s;
       } else {
 	pki = collectInfo(list);
-	break;	
+	break;
       }
     }
   }
@@ -210,21 +212,41 @@ packageInfo *DEB::getIPackageInfo( const QString &name)
   return pki;
 }
 
+packageInfo *DEB::getIRPackageInfo( const QString &name)
+{
+  // query an remote installed package
+  packageInfo *pki = 0;
+
+  QString s = "dpkg --status ";
+  s += name;
+  QStringList list =  kpty->run(s);
+  for ( QStringList::Iterator it = list.begin();  it != list.end(); ++it ) {
+    //    kdDebug() << "U=" << *it << "\n";
+    if ((*it).find("Package:") >= 0) {
+      kdDebug() << "found\n";
+      while (it != list.begin()) {
+	list.remove(list.begin());
+      }
+      break;
+    }
+  }
+
+  if (list.count() > 1) {
+    pki = DEB::collectInfo(list);
+    if (pki) {
+      pki->updated = TRUE;
+      if (pki->getFilename().isEmpty())
+	pki->setFilename(name);
+    }
+  }
+
+  return pki;
+}
+
 packageInfo *DEB::getUPackageInfo( const QString &name)
 {
-  // query an uninstalled package      
-  packageInfo *pki = 0; 
-
-  //  reader.setup("dpkg");
-  //  *reader.proc << "--info"<<name;
-  //  if (reader.start(0)) {
-  //    int p = reader.buf.find("package:",0,FALSE);
-  //    if (p == 0) {
-  //      list = QStringList::split("\n ",reader.buf);
-  //    } else if (p > 0) {
-  //      list = QStringList::split("\n ",reader.buf.mid(p));
-  //    } else
-  //      return 0;
+  // query an uninstalled package
+  packageInfo *pki = 0;
 
   QString s = "dpkg --info ";
   s += name;
@@ -237,11 +259,8 @@ packageInfo *DEB::getUPackageInfo( const QString &name)
 	list.remove(list.begin());
       }
       break;
-    } 
+    }
   }
-  //  for ( QStringList::Iterator iit = list.begin();  iit != list.end(); ++iit ) {
-  //    kdDebug() << "UU=" << *iit << "\n";
-  //  }
 
   if (list.count() > 1) {
     pki = DEB::collectInfo(list);
@@ -309,20 +328,22 @@ packageInfo *DEB::collectInfo(QStringList &ln)
 	delete a;
 	return 0;
       }
-      if (val != "install ok installed" && 
+      if (val != "install ok installed" &&
 	  val != "deinstall ok installed" &&
 	  val != "deinstall ok config-files" &&
 	  val != "purge ok installed") {
 	bad_install = TRUE;
       }
       a->insert("status",  new QString(val));
+    } else if (key == "version") {
+      a->insert("version",  new QString(val));
     } else if (key == "size") {
       a->insert("file-size",  new QString(val));
     } else if (key == "installed-size") {
       a->insert("size",  new QString(val + "000"));
     } else {
       //      printf("[%s=%s]\n",key.data(),val.data());
-      a->insert(key, new QString(val));
+       a->insert(key, new QString(val));
     }
   }
 
@@ -377,46 +398,45 @@ QStringList DEB::getIFileList(packageInfo *p)
 // query an uninstalled package
 QStringList DEB::getUFileList(QString fn)
 {
-  QStringList filelist;
+  QString s = "dpkg --contents ";
+  s += fn;
 
-  reader.setup("dpkg");
-  *reader.proc << "--contents" << fn;
+  QStringList filelist = kpty->run(s);
 
-  if (!reader.start(procMsg))
-    return 0;
-
-  filelist =  QStringList::split("\n",reader.buf);
+  int pt = -1;
   for ( QStringList::Iterator it = filelist.begin();
 	it != filelist.end(); ++it ) {
-    (*it) = (*it).mid((*it).findRev(' ') + 1);
+    //    kdDebug() << "F=" << *it << "\n";
+    if (pt < 0) {
+      pt = (*it).findRev(' ');
+    }
+    (*it) = (*it).mid(pt + 1);
   }
   return filelist;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-QString DEB::FindFile(const QString &name)
+QStringList DEB::FindFile(const QString &name)
 {
-  reader.setup("dpkg");
-  *reader.proc << "-S"<<name;
+  QString s = "dpkg -S ";
+  s += name;
 
-  if (!reader.start(procMsg,FALSE))
-    return "";
+  QStringList filelist = kpty->run(s);
 
-  int p = 0,lines = 0;
-  while ((p = reader.buf.find(':',p)) >= 0) {
-    lines++;
-    reader.buf.replace(p,1,"\t");
-    p = reader.buf.find('\n',p);
+  for ( QStringList::Iterator it = filelist.begin(); it != filelist.end(); ++it ) {
+    int p =  (*it).find(": ");
+    (*it).replace(p, 2, "\t");
   }
 
-  if (lines == 1) {
-    if (reader.buf.find("not found") >= 0)
-      reader.buf.truncate(0);
+  if (filelist.count() == 1) {
+    QStringList::Iterator it = filelist.begin();
+    if ((*it).find("not found") >= 0) {
+      filelist.remove(it);
+    }
   }
 
-
-  return reader.buf;
+  return filelist;
 }
 
 
@@ -438,7 +458,7 @@ void DEB::setAvail(LcacheObj *slist)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-QString DEB::uninstall(int uninstallFlags, QList<packageInfo> *p,
+QString DEB::uninstall(int uninstallFlags, QPtrList<packageInfo> *p,
 				bool &test)
 {
   QString packs = "";
@@ -452,7 +472,7 @@ QString DEB::uninstall(int uninstallFlags, QList<packageInfo> *p,
 }
 
 //////////////////////////////////////////////////////////////////////////////
-QString DEB::install(int installFlags, QList<packageInfo> *p,
+QString DEB::install(int installFlags, QPtrList<packageInfo> *p,
 			      bool &test)
 {
   QString packs = "";
@@ -481,10 +501,11 @@ QString DEB::doInstall(int installFlags, QString packs, bool &test)
   s +=  packs;
 
   kdDebug() << "iCMD=" << s << "\n";
-  
+
   if (installFlags>>4 & 1)
     test = 1;
 
   return s;
 }
 
+#include "debInterface.moc"
