@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debInterface.h,v 1.15 2001/01/14 16:44:21 toivo Exp $ 
+//      $Id: debInterface.h,v 1.20 2001/11/09 15:34:10 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -10,7 +10,7 @@
 
 #include "../config.h"
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qdir.h> 
 #include <qfile.h> 
 #include <qfileinf.h> 
@@ -19,7 +19,6 @@
 
 #include <kprocess.h>
 
-#include "procbuf.h"
 #include "pkgInterface.h"
 
 class packageInfo;
@@ -37,7 +36,7 @@ class DEB: public pkgInterface
   Q_OBJECT
 
 public:
-  DEB(QString remote);
+  DEB();
   ~DEB();
   
   virtual bool isType(char *buf, const QString &fname);
@@ -46,16 +45,16 @@ public:
 			      const QString &version);
   virtual QStringList getFileList(packageInfo *p);
 
-  virtual void listInstalledPackages(QList<packageInfo> *pki);
+  virtual void listInstalledPackages(QPtrList<packageInfo> *pki);
 
-  virtual QString FindFile(const QString &name);
+  virtual QStringList FindFile(const QString &name);
   virtual bool parseName(QString name, QString *n, QString *v);
 
   virtual packageInfo* collectInfo(QStringList &inp);
 
-  QString uninstall(int uninstallFlags, QList<packageInfo> *p,
+  QString uninstall(int uninstallFlags, QPtrList<packageInfo> *p,
 				  bool &test);
-  QString install(int installFlags, QList<packageInfo> *p,
+  QString install(int installFlags, QPtrList<packageInfo> *p,
 				  bool &test);
   QString doInstall(int installFlags, QString packs, bool &test);
 
@@ -65,13 +64,14 @@ public slots:
 
 protected:
   packageInfo *getIPackageInfo(const QString &name);
+  packageInfo *getIRPackageInfo(const QString &name);
   packageInfo *getUPackageInfo(const QString &name);
 
-  void listPackList(QList<packageInfo> *pki,
+  void listPackList(QPtrList<packageInfo> *pki,
 		    const QString &fname, cacheObj *cp);
 
-  void distPackages(QList<packageInfo> *pki, cacheObj *cp);
-  void listUnIPackages(QList<packageInfo> *pki, LcacheObj *pCache);
+  void distPackages(QPtrList<packageInfo> *pki, cacheObj *cp);
+  void listUnIPackages(QPtrList<packageInfo> *pki, LcacheObj *pCache);
 
   QStringList getIFileList(packageInfo *p);
   QStringList getUFileList(QString fn);
