@@ -1,5 +1,5 @@
-//////////////////////////////////////////////////////////////         
-//      $Id: fbsdInterface.cpp,v 1.31 2001/05/17 15:07:48 toivo Exp $
+//////////////////////////////////////////////////////////////
+//      $Id: fbsdInterface.cpp,v 1.34 2001/12/19 11:21:09 binner Exp $
 //
 // Author: Alex Hayward
 // xelah@ferret.lmh.ox.ac.uk
@@ -13,7 +13,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <klocale.h> 
+#include <klocale.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 
@@ -27,7 +27,7 @@
 #define PKG_ADD_BIN "/usr/sbin/pkg_add"
 #define PKG_DELETE_BIN "/usr/sbin/pkg_delete"
 
-fbsdInterface::fbsdInterface(QString remote):pkgInterface(remote) {
+fbsdInterface::fbsdInterface():pkgInterface() {
   head = "BSD";
   name = i18n("BSD");
   icon = "bsd";
@@ -41,14 +41,14 @@ fbsdInterface::fbsdInterface(QString remote):pkgInterface(remote) {
 
   queryMsg = i18n("Querying package list: ");
 
-  locatedialog = new Locations(i18n("Location of BSD packages and ports"));
+  locatedialog = new Locations(i18n("Location of BSD Packages and Ports"));
   locatedialog->dLocations(1, 1, this, i18n("Ports"), "Pkg", "*.tgz",
                            i18n("Location of ports tree (eg /usr/ports or /usr/opt)"),FALSE);
   locatedialog->dLocations(1, 6, this, i18n("Packages"), "Pkg", "*.tgz",
                            i18n("Location of directories containing BSD packages or package trees"));
   connect(locatedialog, SIGNAL(returnVal(LcacheObj *)), this, SLOT(setAvail(LcacheObj *)));
   locatedialog->apply_slot();
-  
+
   paramsInst.append(new param(i18n("Ignore Scripts"),FALSE,FALSE,"-I"));
   paramsInst.append(new param(i18n("Check Dependencies"),TRUE,TRUE,"-f"));
   paramsInst.append(new param(i18n("Test (do not install)"),FALSE,FALSE,"-n"));
@@ -61,7 +61,7 @@ fbsdInterface::fbsdInterface(QString remote):pkgInterface(remote) {
 }
 
 fbsdInterface::~fbsdInterface() {
-  
+
 }
 
 bool fbsdInterface::isType(char *, const QString &fname) {
@@ -74,16 +74,16 @@ bool fbsdInterface::isType(char *, const QString &fname) {
 }
 
 packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, const QString &version) {
-  QString name( pname); 
+  QString name( pname);
   bool installed = false;
   kpackage->setStatus(i18n("Getting package info"));
 
   if (mode == 'i' && !version.isEmpty()) {
     name += "-" + version;
   }
-    
+
   QDict<QString> *a = new QDict<QString>;
-  a->setAutoDelete(TRUE);      
+  a->setAutoDelete(TRUE);
 
   // Get the package name first (for mode = 'u').
   if (mode == 'u') {
@@ -98,7 +98,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
       a->insert("filename", new QString(name));
       a->insert("base", new QString(""));
     }
- 
+
     // Look for a line of the form '@name <pkgname>'
     if (reader.start(0, FALSE)) {
       if (!reader.buf.isNull()) {
@@ -184,7 +184,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
 }
 
   QStringList fbsdInterface::getFileList(packageInfo *p) {
- 
+
   // Run pkg_info on the package name to get the file list.
   // The file list is returned on stdout, one per line.
   kpackage->setStatus(i18n("Getting file list"));
@@ -194,7 +194,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
   // Find the full name 'name-version', or just 'name' if version is empty.
   // Check first that it is actually installed.
   QString name( p->getProperty("filename"));
- 
+
   if (!name.isEmpty() && (p->packageState != packageInfo::INSTALLED)) {
     QString qbname( p->getProperty("base"));
     if (!qbname.isEmpty())
@@ -207,7 +207,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
     }
 
     name = p->getProperty("name");
- 
+
     QString version( p->getProperty("version"));
     if (!version.isEmpty()) {
        name = name + "-" + version;
@@ -236,15 +236,15 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
   } else {
     ret.append(i18n("Can't start pkg_info"));
   }
-  
+
   kpackage->setStatus("");
   return ret;
 }
 
 
-//  QList<char> *verify(packageInfo *p, QList<char> *files);
+//  QPtrList<char> *verify(packageInfo *p, QPtrList<char> *files);
 
-QString fbsdInterface::doUninstall(int uninstallFlags, QString packs, bool &) 
+QString fbsdInterface::doUninstall(int uninstallFlags, QString packs, bool &)
 {
 
   QString s = PKG_DELETE_BIN;
@@ -258,7 +258,7 @@ QString fbsdInterface::doUninstall(int uninstallFlags, QString packs, bool &)
 }
 
 
-QString fbsdInterface::doInstall(int installFlags, QString packs, bool &) 
+QString fbsdInterface::doInstall(int installFlags, QString packs, bool &)
 {
 
   QString s = PKG_ADD_BIN;
@@ -280,7 +280,7 @@ QString fbsdInterface::uninstall(int uninstallFlags, packageInfo *p, bool &test)
   return doUninstall(uninstallFlags, packs, test);
 }
 
-QString fbsdInterface::uninstall(int uninstallFlags, QList<packageInfo> *p, bool &test)
+QString fbsdInterface::uninstall(int uninstallFlags, QPtrList<packageInfo> *p, bool &test)
 {
   QString packs = "";
   packageInfo *i;
@@ -354,7 +354,7 @@ void fbsdInterface::setAvail(LcacheObj *slist) {
 }
 
 
-void fbsdInterface::listPackages(QList<packageInfo> *pki) {
+void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
   int listscan;
 
   listInstalledPackages(pki);
@@ -396,9 +396,9 @@ void fbsdInterface::listPackages(QList<packageInfo> *pki) {
   }
 }
 
-void fbsdInterface::listInstalledPackages(QList<packageInfo> *pki) {
+void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 #define INFO_SEPARATOR "f;g#z-@IqbX%"
-  
+
   // Open a pipe to a pkg_info process in order to read the comment, name
   // and description for the packages.
 
@@ -516,7 +516,7 @@ void fbsdInterface::listInstalledPackages(QList<packageInfo> *pki) {
       }
 
       a->insert("description", desc);
-      
+
       packageInfo *info = new packageInfo(a, this);
       info->packageState = packageInfo::INSTALLED;
       info->fixup();
@@ -527,7 +527,7 @@ void fbsdInterface::listInstalledPackages(QList<packageInfo> *pki) {
       }
     free(buf);
     }
-    
+
 #undef INFO_SEPARATOR
 }
 
@@ -579,7 +579,7 @@ bsdPortsIndexItem::bsdPortsIndexItem(char *desc, bool binaries, QString dname) :
 
   if (itemno != 8 && itemno != 9) {
      KpMsgE(i18n("Warning: invalid INDEX file entry for %1").arg(name),FALSE);
-  } 
+  }
     name_hash = calc_hash4(name);
 
     // Order the entries by hash.
@@ -629,7 +629,7 @@ unsigned char bsdPortsIndexItem::hash1(unsigned int h) {
 
 void bsdPortsIndexItem::processFile(const QString &fname, bool binaries, const QString &dname) {
   // Read the file in to a buffer and null terminate it.
-  
+
   struct stat s;
 
   if (stat(fname.ascii(), &s) == -1) {
@@ -662,7 +662,7 @@ void bsdPortsIndexItem::processFile(const QString &fname, bool binaries, const Q
 
 bsdPortsIndexItem *bsdPortsIndexItem::find(const QString &name) {
   if (name.isEmpty()) return 0;
- 
+
   unsigned int hash = calc_hash4(name.ascii());
 
   bsdPortsIndexItem *scan = lists[hash1(hash)];
