@@ -1,5 +1,5 @@
-//////////////////////////////////////////////////////////////         
-//      $Id: kissInterface.cpp,v 1.24 2001/01/14 16:44:21 toivo Exp $ 
+//////////////////////////////////////////////////////////////
+//      $Id: kissInterface.cpp,v 1.33 2001/12/28 00:58:03 mueller Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -13,8 +13,8 @@
 #include <time.h>
 #include <setjmp.h>
 
-#include <qdir.h> 
-#include <qfileinf.h> 
+#include <qdir.h>
+#include <qfileinfo.h>
 
 #include <kurl.h>
 #include <kglobal.h>
@@ -26,7 +26,6 @@
 #include "kpackage.h"
 #include "managementWidget.h"
 #include "utils.h"
-#include "procbuf.h"
 #include "options.h"
 #include "cache.h"
 #include <klocale.h>
@@ -36,11 +35,11 @@ extern KApplication *app;
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-KISS::KISS(QString remote):pkgInterface(remote)
+KISS::KISS():pkgInterface()
 {
   head = "KISS";
   name = i18n("KISS");
-  icon = "kiss";  
+  icon = "kiss";
 
   pict = UserIcon(icon);
   updated_pict = UserIcon("kupdated");
@@ -49,10 +48,10 @@ KISS::KISS(QString remote):pkgInterface(remote)
   packagePattern = "*.installer";
   typeID = "/kiss";
 
-  locatedialog = new Locations(i18n("Location of KISS packages"));
+  locatedialog = new Locations(i18n("Location of KISS Packages"));
   locatedialog->dLocations(2, 6, this,  i18n("D"),
   "KISS", "*.installer",
-  i18n("Location of directories containg KISS packages"));
+  i18n("Location of directories containing KISS packages"));
 
   connect(locatedialog,SIGNAL(returnVal(LcacheObj *)),
          this,SLOT(setAvail(LcacheObj *)));
@@ -106,18 +105,18 @@ bool KISS::parseName(QString name, QString *n, QString *v)
   return FALSE;
 }
 
-void KISS::listInstalledPackages(QList<packageInfo> *pki)
+void KISS::listInstalledPackages(QPtrList<packageInfo> *pki)
 {
   QString vb;
   packageInfo *p;
 
   QString sline = i18n("Querying KISS package list: ");
- 
+
   reader.setup("kiss");
   *reader.proc << "-qq";
   if (!reader.start(0,FALSE))
     return;
-  
+
   kpackage->setStatus(sline);
   kpackage->setPercent(0);
 
@@ -129,7 +128,7 @@ void KISS::listInstalledPackages(QList<packageInfo> *pki)
       break;
     p = collectInfo(reader.buf.mid(sp,sc-sp).ascii());
     if (p) {
-      if (!p->update(pki, typeID, TRUE)) {
+      if (!p->pkgInsert(pki, typeID, TRUE)) {
 	delete p;
       }
     }
@@ -144,9 +143,9 @@ void KISS::listInstalledPackages(QList<packageInfo> *pki)
 // mode: i = query installed    u = query uninstalled
 packageInfo *KISS::getPackageInfo(char mode, const QString &name, const QString &)
 {
-  packageInfo *pki = 0; 
+  packageInfo *pki = 0;
   QString vb,search;
-  
+
   switch(mode)
     {
       ////////////////////////////////////////////////////////////////////////
@@ -157,11 +156,11 @@ packageInfo *KISS::getPackageInfo(char mode, const QString &name, const QString
       if (reader.start(0,FALSE)) {
 	reader.buf += "package: " + name + "\n";
 	pki = collectInfo(reader.buf.ascii());
-      }	
+      }
       break;
 
       ////////////////////////////////////////////////////////////////////
-      // query an uninstalled package      
+      // query an uninstalled package
     case 'u':
       reader.setup("perl");
       *reader.proc << name << "-q";
@@ -189,7 +188,7 @@ packageInfo *KISS::collectInfo(const char *_inp)
   char *str, *xstr;
   QString qstr;
 
-  char *inp = qstrdup(_inp); 
+  char *inp = qstrdup(_inp);
   str = strtok(inp,"\n");
   do {
     xstr = strchr(str,':');
@@ -200,7 +199,7 @@ packageInfo *KISS::collectInfo(const char *_inp)
   } while ((str = strtok(NULL,"\n")));
 
   // parse 'name: text' elements
-    
+
   if (str) {
     do {
       if (str[0] == 0)
@@ -210,7 +209,7 @@ packageInfo *KISS::collectInfo(const char *_inp)
     if (xstr) {
       *xstr++ = 0;
       xstr++;
-	  
+
       qstrcpy(str, QString(str).lower().ascii());
       if (*str == ' ')
 	str++;
@@ -280,7 +279,7 @@ QStringList KISS::getFileList(packageInfo *p)
       break;
 
       ////////////////////////////////////////////////////////////////////
-      // query an uninstalled package      
+      // query an uninstalled package
     case 'u':
       reader.setup("perl");
       *reader.proc << fn << "-f";
@@ -296,7 +295,7 @@ QStringList KISS::getFileList(packageInfo *p)
       }
       break;
     }
-   
+
   return filelist;
 }
 
@@ -304,7 +303,7 @@ QStringList KISS::getFileList(packageInfo *p)
 // Call the script to install packages setting parameters
 // to kiss dependent on flags
 //////////////////////////////////////////////////////////////////////////////
-QString KISS::uninstall(int uninstallFlags, QList<packageInfo> *plist, bool &test)
+QString KISS::uninstall(int uninstallFlags, QPtrList<packageInfo> *plist, bool &test)
 {
   QString packs;
   packageInfo *pk;
@@ -319,9 +318,9 @@ QString KISS::uninstall(int uninstallFlags, QList<packageInfo> *plist, bool &tes
 QString KISS::doUninstall(int, QString packs, bool &)
 {
   QString s = "kiss ";
-  s += "-d "; 
+  s += "-d ";
   s += packs;
-  
+
   return s;
 }
 
@@ -329,7 +328,7 @@ QString KISS::doUninstall(int, QString packs, bool &)
 // Call the script to install packages setting parameters
 // to kiss dependent on flags, returning whether everyting worked
 //////////////////////////////////////////////////////////////////////////////
-QString KISS::install(int installFlags, QList<packageInfo> *plist, bool &test)
+QString KISS::install(int installFlags, QPtrList<packageInfo> *plist, bool &test)
 {
   packageInfo *pk;
   int i = 0;
@@ -342,32 +341,28 @@ QString KISS::install(int installFlags, QList<packageInfo> *plist, bool &test)
   }
   return 0;
 }
- 
+
 QString KISS::doInstall(int, QString packs, bool &)
 {
   QString s = "perl ";
   s += packs;
-  
+
   return s;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-QString KISS::FindFile(const QString &name)
+QStringList KISS::FindFile(const QString &name)
 {
-  QString buf;
+  QString s = "kiss -p ";
+  s += name;
 
-  reader.setup("kiss");
-  *reader.proc << "-p"<<name;
+  QStringList filelist = kpty->run(s);
 
-  if (!reader.start(procMsg,FALSE))
-    return "";
+  for ( QStringList::Iterator it = filelist.begin(); it != filelist.end(); ++it )
+    *it = *it + '\t' + name ;
 
-  QStringList list = QStringList::split('\n', reader.buf);
-  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
-    buf += *it + '\t' + name + '\n';
-
-  return buf;
+  return filelist;
 }
 
 
@@ -389,3 +384,4 @@ void KISS::setAvail(LcacheObj *slist)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "kissInterface.moc"
