@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: kissInterface.h,v 1.10 2001/01/14 16:44:21 toivo Exp $ 
+//      $Id: kissInterface.h,v 1.13 2001/09/26 16:33:31 mlaurent Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -10,7 +10,7 @@
 
 #include "../config.h"
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 #include <kprocess.h>
 
@@ -26,7 +26,7 @@ class KISS: public pkgInterface
   Q_OBJECT
 
 public:
-  KISS(QString remote);
+  KISS();
   ~KISS();
   
   bool isType(char *buf, const QString &fname);
@@ -35,7 +35,7 @@ public:
   packageInfo *getPackageInfo(char mode, const QString &name, const QString &version);
   QStringList getFileList(packageInfo *p);
 
-  QString FindFile(const QString &name);
+  QStringList FindFile(const QString &name);
   bool parseName(QString name, QString *n, QString *v);
 
 public slots:
@@ -44,10 +44,10 @@ public slots:
 
 private:
   packageInfo* collectInfo(const char *inp);
-  void listInstalledPackages(QList<packageInfo> *pki);
+  void listInstalledPackages(QPtrList<packageInfo> *pki);
  
-  QString install(int installFlags, QList<packageInfo> *plist, bool &test);
-  QString uninstall(int uninstallFlags, QList<packageInfo> *plist, bool &test);
+  QString install(int installFlags, QPtrList<packageInfo> *plist, bool &test);
+  QString uninstall(int uninstallFlags, QPtrList<packageInfo> *plist, bool &test);
 
   QString doUninstall(int installFlags, QString packs, bool &test);
   QString doInstall(int installFlags, QString packs, bool &test);
