@@ -1,5 +1,5 @@
 ///////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.cpp,v 1.47 2001/02/13 16:28:50 toivo Exp $	
+// $Id: managementWidget.cpp,v 1.58 2002/03/06 13:39:37 toivo Exp $
 // File  : managementWidget.cpp
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -7,7 +7,7 @@
 // See managementWidget.h for more information
 
 #include <qsplitter.h>
-#include <qstack.h>
+#include <qptrstack.h>
 
 #include <klocale.h>
 
@@ -27,9 +27,12 @@ extern Opts *opts;
 managementWidget::managementWidget(QWidget *parent)
   : QFrame(parent)
 {
+  install_action=0;
+  uninstall_action=0;
   package=0;
-  installedPackages=0;
-  QStack<QString> stack();
+
+  allPackages  = new QPtrList<packageInfo>;
+  QPtrStack<QString> stack();
 
   tType[0] = i18n("Installed");
   tType[1] = i18n("Updated");
@@ -44,8 +47,8 @@ managementWidget::managementWidget(QWidget *parent)
 
 managementWidget::~managementWidget()
 {
-  //  if(installedPackages)
-  //      delete installedPackages;
+  //  if(allPackages)
+  //      delete allPackages;
   //  delete dirInstPackages;
   //  delete dirUninstPackages;
 }
@@ -94,7 +97,7 @@ void managementWidget::setupWidgets()
 
   for (int i = 0; i < 4; i++) {
     QTab *t = new QTab();
-    t->label = tType[i];
+    t->setText( tType[i] );
     ltab->addTab(t);
   }
   connect(ltab,SIGNAL(selected (int)),SLOT(tabChanged(int)));
@@ -109,11 +112,11 @@ void managementWidget::setupWidgets()
 
   lbuttons = new QBoxLayout(QBoxLayout::LeftToRight);
 
-  luinstButton = new QPushButton(i18n("Uninstall marked"),leftpanel);
+  luinstButton = new QPushButton(i18n("Uninstall Marked"),leftpanel);
   luinstButton->setEnabled(TRUE);
   connect(luinstButton,SIGNAL(clicked()),
 	  SLOT(uninstallMultClicked()));
-  linstButton = new QPushButton(i18n("Install marked"),leftpanel);
+  linstButton = new QPushButton(i18n("Install Marked"),leftpanel);
   linstButton->setEnabled(TRUE);
   connect(linstButton,SIGNAL(clicked()),
 	  SLOT(installMultClicked()));
@@ -206,22 +209,38 @@ void managementWidget::readTreeType()
 }
 
 ///////////////////////////////////////////////////////////////////
-void managementWidget::setupInstButton(packageInfo *p)
+void managementWidget::setupInstButton()
 {
-  if (p->interface->noFetch || !package->getFilename().isEmpty() ) {
-    instButton->setText(i18n("Install"));
-  } else {
-    instButton->setText(i18n("Fetch"));
+  bool u,i;
+  if (!package)
+  {
+    i = false;
+    u = false;
   }
-  if (p->packageState != packageInfo::INSTALLED &&
-      !package->getProperty("filename").isNull() ) {
+  else
+  {
+    if (package->interface->noFetch || !package->getFilename().isEmpty() ) {
+      instButton->setText(i18n("Install"));
+    } else {
+      instButton->setText(i18n("Fetch"));
+    }
+    if (package->packageState != packageInfo::INSTALLED &&
+        !package->getProperty("filename").isNull() ) {
 
-    instButton->setEnabled(TRUE);
-    uinstButton->setEnabled(FALSE);
-  } else {
-    instButton->setEnabled(FALSE);
-    uinstButton->setEnabled(TRUE);
+      i = true;
+      u = false;
+    } else {
+      i = false;
+      u = true;
+    }
   }
+  instButton->setEnabled(i);
+  if (install_action)
+    install_action->setEnabled(i);
+
+  uinstButton->setEnabled(u);
+  if (uninstall_action)
+     uninstall_action->setEnabled(u);
 }
 
 void managementWidget::arrangeWidgets()
@@ -241,7 +260,7 @@ void managementWidget::collectData(bool refresh)
 {
   int i;
 
-  if (!refresh && installedPackages) {
+  if (!refresh && allPackages) {
     sweep();
     return; // if refresh not required already initialised
   }
@@ -259,19 +278,21 @@ void managementWidget::collectData(bool refresh)
   packageDisplay->noPackage();
 
   // Delete old list if necessary
-  if(installedPackages) {
-    delete installedPackages;
+  if(allPackages) {
+    delete allPackages;
   }
 
-  installedPackages = new QList<packageInfo>;
-  installedPackages->setAutoDelete(TRUE);
+  allPackages = new QPtrList<packageInfo>;
+  allPackages->setAutoDelete(TRUE);
 
   dirInstPackages->clear();
   dirUninstPackages->clear();
   // List installed packages
   for (i = 0; i < kpinterfaceN; i++)  {
     if (kpinterface[i] && opts->handlePackage[i]) {
-      kpinterface[i]->listPackages(installedPackages);
+      if (hostName.isEmpty() || (kpinterface[i]->hasRemote)) {
+	kpinterface[i]->listPackages(allPackages);
+      }
     }
   }
 
@@ -290,22 +311,30 @@ void managementWidget::rebuildListTree()
   kpackage->setStatus(i18n("Building package tree"));
   kpackage->setPercent(0);
 
+  treeList->setSorting(-1);
 
   // place all the packages found
-  int count = installedPackages->count();
+  int count = allPackages->count();
+  int incr = count/50;
+  if (incr == 0)
+    incr = 1;
 
-  for(i=installedPackages->first(); i!=0; i=installedPackages->next())
+  for(i=allPackages->first(); i!=0; i=allPackages->next())
     {
       i->place(treeList,TRUE);
 
-      int num = (n*100)/count;
-      if (!(num % 5))
-	kpackage->setPercent(num);
+      if (!(n % incr)) {
+	kpackage->setPercent(int (n*100/count));
+      }
       n++;
     }
   treeList->show();		// show the list tree
   sweep();
+
+  treeList->setSorting(0);
+
   kpackage->setPercent(100);	// set the progress
+  kpackage->setStatus("");
 }
 
 // A package has been highlighted in the list tree
@@ -315,7 +344,8 @@ void managementWidget::packageHighlighted(QListViewItem *item)
   KPLVItem *sel = (KPLVItem *)item;
 
   if (!sel || sel->childCount()) {
-    emit changePackage(NULL);
+    emit changePackage(0);
+    package = 0;
   } else if (sel) {
 
     if (!notPress) {
@@ -334,17 +364,16 @@ void managementWidget::packageHighlighted(QListViewItem *item)
 
     // Keep copy of the package
     package = sel->info;
-    if (package) {
-      setupInstButton(package);
-    }
 
     // Re-enable the treeList and uninstall button
     treeList->setEnabled(TRUE);
+    treeList->setFocus();
 
     if (!notPress) {
       stack.append(sel);
     }
   }
+  setupInstButton();
 
   notPress = false;
   // Update the status bar
@@ -357,11 +386,11 @@ void managementWidget::packageHighlighted(QListViewItem *item)
 void managementWidget::installSingleClicked()
 {
   int result;
-  QList<packageInfo> plist;
-  QString filename = package->getFilename();
-  kdDebug() << "File=" << filename << "\n";
+  QPtrList<packageInfo> plist;
 
   if (package) {
+    QString filename = package->getFilename();
+    kdDebug() << "File=" << filename << "\n";
     pkgInterface *interface = package->interface;
     if (interface->noFetch || !filename.isEmpty()) {
       plist.append(package);
@@ -375,9 +404,9 @@ void managementWidget::installSingleClicked()
 	  updatePackage(inf,TRUE);
 	}
 
-	emit changePackage(NULL); // change package to no package
-	package = NULL;
-	instButton->setEnabled(FALSE); // disable install button
+	emit changePackage(0); // change package to no package
+	package = 0;
+        setupInstButton();
       }
     } else {
       QString url = package->getUrl();
@@ -385,7 +414,7 @@ void managementWidget::installSingleClicked()
 	QString s = kpackage->fetchNetFile(url);
 	if (!s.isEmpty()) {
 	  emit changePackage(package);
-	  setupInstButton(package);
+	  setupInstButton();
 	}
       } else {
 	KpMsgE(i18n("Filename not available\n"),TRUE);
@@ -401,13 +430,13 @@ void managementWidget::installMultClicked()
   int  i;
   KPLVItem *it;
   packageInfo *inf;
-  QList<packageInfo> **lst = new QList<packageInfo>*[kpinterfaceN];
+  QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
   findMarked(treeList->firstChild());
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      lst[i] = new QList<packageInfo>;
+      lst[i] = new QPtrList<packageInfo>;
       for (it = selList.first(); it != 0; it = selList.next()) {
 	if (it->info->interface == kpinterface[i] &&
 	    it->childCount() == 0 &&
@@ -443,7 +472,7 @@ void managementWidget::installMultClicked()
 void managementWidget::uninstallSingleClicked()
 {
   int result;
-  QList<packageInfo> plist;
+  QPtrList<packageInfo> plist;
 
   if (package) {			// check that there is a package to uninstall
     pkgInterface *interface = package->interface;
@@ -458,9 +487,9 @@ void managementWidget::uninstallSingleClicked()
 	updatePackage(inf,FALSE);
       }
 
-      emit changePackage(NULL); // change package to no package
-      package = NULL;
-      uinstButton->setEnabled(FALSE); // disable uninstall button
+      emit changePackage(0); // change package to no package
+      package = 0;
+      setupInstButton();
     }
   }
   kpackage->setPercent(100);
@@ -471,13 +500,13 @@ void managementWidget::uninstallMultClicked()
   int  i;
   KPLVItem *it;
   packageInfo *inf;
-  QList<packageInfo> **lst = new QList<packageInfo>*[kpinterfaceN];
+  QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
   findMarked(treeList->firstChild());
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      lst[i] = new QList<packageInfo>;
+      lst[i] = new QPtrList<packageInfo>;
       for (it = selList.first(); it != 0; it = selList.next()) {
 	if (it->info->interface == kpinterface[i] &&
 	    it->childCount() == 0 &&
@@ -541,7 +570,7 @@ int  managementWidget::sweepChild(KPLVItem *it)
       } else {
 	it->show();
 	shown++;
-      }	
+      }
     }
   } while ((it = it->nextSibling()));
   return shown;
@@ -646,7 +675,7 @@ KPLVItem *managementWidget::changePack(KPLVItem *searchResult, bool push)
 
     i = searchResult;
     while ((i = i->parent())) {
-      i->setOpen(TRUE);	
+      i->setOpen(TRUE);
     }
     if (push) {
       stack.append(searchResult);
@@ -701,8 +730,9 @@ void managementWidget::previous()
 KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 {
   QString version;
+  KPLVItem *q;
 
-  if (installedPackages) {
+  if (allPackages) {
     QString name(pki->getProperty("name"));
     if (pki->hasProperty("version"))
       version = pki->getProperty("version");
@@ -711,40 +741,44 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
     pkgInterface *interface = pki->interface;
     packageInfo *pnew = interface->getPackageInfo('i', name, version);
     packageInfo *ptree;
-    QString dirIndex =  name + interface->typeID;
+    QString pkgId =  name + interface->typeID;
 
     if (install) {
       if (pnew) {
 	if (pnew->packageState !=  packageInfo::BAD_INSTALL) {
-	  ptree = dirInstPackages->find(dirIndex); // remove installed entry
-	  dirInstPackages->remove(dirIndex);
+	  ptree = dirInstPackages->find(pkgId); // remove installed entry
+	  dirInstPackages->remove(pkgId);
 	  if (ptree) {
-	    if (ptree->getItem())
+	    if (ptree->getItem()) {
 	      delete ptree->getItem();
+	      ptree->item = 0;
+	    }
 	  }
 
-	  ptree = dirUninstPackages->find(dirIndex); // remove uninstalled entry
-	  dirUninstPackages->remove(dirIndex);
+	  ptree = dirUninstPackages->find(pkgId); // remove uninstalled entry
 	  if (ptree) {
-	    if (ptree->getItem())
-	      delete ptree->getItem();	
+	    ptree->packageState = packageInfo::HIDDEN;
+	    if (ptree->getItem()) {
+	      delete ptree->getItem();
+	      ptree->item = 0;
+	    }
 	  }
 	}
 
-	dirInstPackages->insert(dirIndex,pnew);
+	dirInstPackages->insert(pkgId,pnew);
 
-	KPLVItem *q = pnew->place(treeList,TRUE);
-	installedPackages->insert(0,pnew);
+	q = pnew->place(treeList,TRUE);
+	allPackages->insert(0,pnew);
 	if (!q) {
-	  //          printf("NOTP=%s \n",pnew->getProperty("name").ascii());
+	  printf("NOTP=%s \n",pnew->getProperty("name").ascii());
 	} else {
 	  sweep();
 	  return q;
 	}
       }
-    } else {
+    } else { // uninstalling
       if (!pnew) {
-	dirInstPackages->remove(dirIndex);
+	dirInstPackages->remove(pkgId);
 	KPLVItem  *qt = pki->getItem();
 	if (qt) {
 	  stackRemove(qt);
@@ -755,6 +789,18 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	} else {
 	  kdDebug() << "DEL=" << name << endl;
 	}
+	packageInfo *pb = dirUninstPackages->find(pkgId);
+	if (pb) { // available package matching the one just uninstalled
+	  pb->packageState = packageInfo::NEW;
+	  q = pb->place(treeList,TRUE);
+	  if (!q) {
+	    printf("NOTP=%s \n",pb->getProperty("name").ascii());
+	  } else {
+	    sweep();
+	    return q;
+	  }
+	}
+
       } else {
 	delete pnew;
       }
@@ -881,3 +927,4 @@ void managementWidget::readTreePos()
 }
 
 
+#include "managementWidget.moc"
