@@ -1,5 +1,5 @@
 ////////////////////////////////////////////////////////////////////////////////
-//      $Id: packageDisplay.cpp,v 1.31 2001/05/17 15:07:48 toivo Exp $ 
+//      $Id: packageDisplay.cpp,v 1.34 2002/02/18 10:58:01 mlaurent Exp $ 
 // File  : packageDisplay.cpp
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -12,14 +12,13 @@
 
 // Qt headers
 
-#include <qapp.h>
-#include <qfileinf.h> 
+#include <qapplication.h>
+#include <qfileinfo.h> 
 
 #include <kiconloader.h> 
 #include <kglobal.h>
 #include <krun.h>
 #include <kopenwith.h>
-#include <ktexteditor.h>
 // kpackage.headers
 #include "kpackage.h"
 #include "packageDisplay.h"
@@ -63,9 +62,10 @@ void packageDisplayWidget::setupWidgets()
   fileList = new KListView(fltab);
   fileList->hide();
   fileList->addColumn("name");
-  connect(fileList, SIGNAL(selectionChanged(QListViewItem *)),
+  connect(fileList, SIGNAL(clicked(QListViewItem *)),
+            this, SLOT( openBinding(QListViewItem *)) );
+  connect(fileList, SIGNAL(returnPressed(QListViewItem *)),
             this, SLOT( openBinding(QListViewItem *)) );
-
   addTab(proptab, i18n("Properties"));
   addTab(fltab, i18n("File List"));
 
@@ -117,8 +117,10 @@ void packageDisplayWidget::changePackage(packageInfo *p)
   bool tfl = fileList->isVisible();
 
 // This is to stop selectionChanged firing off here
-  disconnect(fileList, SIGNAL(selectionChanged(QListViewItem *)),
-	     this, SLOT( openBinding(QListViewItem *)) );
+  disconnect(fileList, SIGNAL(clicked(QListViewItem *)),
+            this, SLOT( openBinding(QListViewItem *)) );
+  disconnect(fileList, SIGNAL(returnPressed(QListViewItem *)),
+            this, SLOT( openBinding(QListViewItem *)) );
 
    if (package && package != p) {
      if (!package->getItem() && !kpackage->management->allPackages->find(package)) {
@@ -154,8 +156,10 @@ void packageDisplayWidget::changePackage(packageInfo *p)
     if (tfl)
       tabSelected(i18n("File List"));          
   }
-  connect(fileList, SIGNAL(selectionChanged(QListViewItem *)),
-	  this, SLOT( openBinding(QListViewItem *)) );
+  connect(fileList, SIGNAL(clicked(QListViewItem *)),
+            this, SLOT( openBinding(QListViewItem *)) );
+  connect(fileList, SIGNAL(returnPressed(QListViewItem *)),
+            this, SLOT( openBinding(QListViewItem *)) );
  }
 
 // update the file list
