@@ -1,6 +1,6 @@
 
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: packageInfo.cpp,v 1.28 2001/07/20 14:55:35 toivo Exp $
+// $Id: packageInfo.cpp,v 1.29 2001/09/26 16:33:31 mlaurent Exp $
 // File  : packageInfo.cpp
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -112,7 +112,7 @@ void packageInfo::setFilename(QString f)
 QString packageInfo::getUrl()
 {
   if (url.isEmpty()) {
-    if (hasProperty("base") && hasProperty("filename")) 
+    if (hasProperty("base") && hasProperty("filename"))
     {
       url = getProperty("base") + "/" + getProperty("filename");
     }
@@ -151,7 +151,7 @@ int packageInfo::getDigElement(QString s, int *pos)
   // Extract the next element from the string
   // All digits
 {
-  if (*pos < 0) 
+  if (*pos < 0)
     return -1;
 
   s = s.mid(*pos);
@@ -171,7 +171,7 @@ int packageInfo::getDigElement(QString s, int *pos)
       val = s.toInt();
       nf = s.length();
     }
-  } 
+  }
 
   //  printf("n=%s %d %d\n",s.mid(nf,999).data(),nf,val);
   *pos += nf;
@@ -207,7 +207,7 @@ QString packageInfo::getNdigElement(QString s, int *pos)
 	str[i] = t;
       }
     }
-  } 
+  }
   *pos += nf;
   return str;
 }
@@ -264,9 +264,9 @@ static bool split(QString orig, char seperator, QString &first, QString &second)
     second = orig.mid(pos+1);
     return true;
   }
-  return false; 
+  return false;
 }
- 
+
 int packageInfo::newer(packageInfo *p)
 {
   QString mySerial;  // Serial number of this package
@@ -296,7 +296,7 @@ int packageInfo::newer(packageInfo *p)
   {
     s = p->getProperty("serial") + ":" + s;
   }
-  
+
   (void) split(s, ':', hisSerial, s);
   if (!split(s, '-', hisVersion, hisRelease))
   {
@@ -490,7 +490,7 @@ void packageInfo::pkgFileIns(QString fileName)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-bool packageInfo::pkgInsert(QList<packageInfo> *pki, const QString &exp,
+bool packageInfo::pkgInsert(QPtrList<packageInfo> *pki, const QString &exp,
 			 bool installed, bool infoPackage)
 {
   QDict<packageInfo> *dirInstPackages = kpackage->management->dirInstPackages;
@@ -549,7 +549,7 @@ bool packageInfo::pkgInsert(QList<packageInfo> *pki, const QString &exp,
 	    if (pi->hasProperty("old-version")) {
 	      info->insert("old-version",
 			   new QString(pi->getProperty("old-version")));
-	    } else { 
+	    } else {
 	      info->insert("old-version",new QString(version));
 	    }
 	    QString group = getProperty("group");
