@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//     $Id: rpmInstall.cpp,v 1.38.2.1 2001/08/24 14:51:32 bero Exp $
+//     $Id: rpmInstall.cpp,v 1.40 2001/11/05 12:55:39 toivo Exp $
 #include "../config.h"
 
 #ifdef HAVE_RPM
@@ -102,12 +102,13 @@ static void * showProgress(const void *hd, const rpmCallbackType what,
 	    if (flags & INSTALL_HASH) {
 		s = headerSprintf(h, "%{NAME}",
 				  rpmTagTable, rpmHeaderFormats, NULL);
-		KpMsgE(QString("%1\n").arg(s,28));
-		fflush(stdout);
+		//		KpMsgE(QString("%1\n").arg(s,28));
+		kdDebug() << "RPMCALLBACK_INST_START:" << s << "\n";
 	    } else {
 		s = headerSprintf(h, "%{NAME}-%{VERSION}-%{RELEASE}", 
 				  rpmTagTable, rpmHeaderFormats, NULL);
-		KpMsgE(QString("%1\n").arg(s));
+		//		KpMsgE(QString("%1\n").arg(s));
+		kdDebug() << "RPMCALLBACK_INST_START : " << s << "\n";
 	    }
 	    free(s);
 	}
@@ -305,20 +306,17 @@ int doInstal(const char * rootdir, const QStringList &argv, int transFlags,
     errs +=  i18n("Found %1 source and %2 binary packages\n").arg(numSourcePackages).arg(numBinaryPackages);
 
     if (numBinaryPackages && !(interfaceFlags & INSTALL_NODEPS)) {
-	if (rpmdepCheck(rpmdep, &conflicts, &numConflicts)) {
-	    numFailed = numPackages;
-	    stopInstall = 1;
-	    if (!stopInstall && conflicts) {
+	kdDebug() <<  conflicts << " rpmdepCheck() failed.\n";
+	if (!rpmdepCheck(rpmdep, &conflicts, &numConflicts)) {
+	    if (conflicts) {
+   	        stopInstall = 1;
+	        numFailed = numPackages;
 	        errs += KprintDepProblems(stderr, conflicts, numConflicts);
 	        rpmdepFreeConflicts(conflicts, numConflicts);
-	        numFailed = numPackages;
-	        stopInstall = 1;
+	    } else {
+	        kdDebug() << " Dependency check problem\n";
 	    }
-	} else {
-	    errs += i18n("rpmdepCheck() failed.");
-	    numFailed = numPackages;
-	    stopInstall = 1;
-	}
+	} 
     }
 
     if (numBinaryPackages && !(interfaceFlags & INSTALL_NOORDER)) {
@@ -505,20 +503,18 @@ int doUninstal(const char * rootdir, const QStringList &argv, int transFlags,
     }
 
     if (!(interfaceFlags & UNINSTALL_NODEPS)) {
-	if (rpmdepCheck(rpmdep, &conflicts, &numConflicts)) {
-	    numFailed = numPackages;
-	    stopUninstall = 1;
-	    if (!stopUninstall && conflicts) {
+	if (!rpmdepCheck(rpmdep, &conflicts, &numConflicts)) {
+	    kdDebug() << numConflicts << " rpmdepCheck() failed.\n";
+	    if (conflicts) {
+	        numFailed = numPackages;
+	        stopUninstall = 1;
 	        errs += KprintDepProblems(stderr, conflicts, numConflicts);
 	        rpmdepFreeConflicts(conflicts, numConflicts);
 	        numFailed += numPackages;
-	        stopUninstall = 1;
+	    } else {
+	        kdDebug() << " Dependency check problem\n";
 	    }
-	} else {
-	    errs += i18n("rpmdepCheck() failed.");
-	    numFailed = numPackages;
-	    stopUninstall = 1;
-	}
+	} 
     }
 
     if (!stopUninstall) {
