@@ -1,5 +1,5 @@
-//////////////////////////////////////////////////////////////         
-//      $Id: search.cpp,v 1.10 2000/08/05 19:45:51 bieker Exp $ 
+//////////////////////////////////////////////////////////////
+//      $Id: search.cpp,v 1.14 2001/10/15 14:14:12 toivo Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -10,14 +10,21 @@
 #include "search.h"
 #include <klocale.h>
 #include <qlineedit.h>
+#include <qcheckbox.h>
 
 Search::Search(QWidget *parent, const char * name)
-    : QDialog(parent, name,FALSE){
+    : KDialogBase(parent, name, false,
+		i18n("Find Package"),
+		User1 | Close, User1, true,
+		i18n("&Find"))
+{
+    QFrame *page = makeMainWidget();
 
-    this->setFocusPolicy(QWidget::StrongFocus);
-    QVBoxLayout* vtop = new QVBoxLayout( this, 10, 10, "vtop");
+    setFocusPolicy(QWidget::StrongFocus);
 
-    frame1 = new QGroupBox(i18n("Find Package"), this, "frame1");
+    QVBoxLayout* vtop = new QVBoxLayout( page, 10, 10, "vtop");
+
+    QFrame *frame1 = new QGroupBox(i18n("Find Package"), page, "frame1");
     vtop->addWidget(frame1,1);
     QVBoxLayout* vf = new QVBoxLayout( frame1, 20, 10, "vf");
 
@@ -25,6 +32,8 @@ Search::Search(QWidget *parent, const char * name)
     vf->addWidget(value,0);
     value->setFocus();
     value->setFixedHeight(value->sizeHint().height());
+    value->setMinimumWidth(250);
+    connect(value, SIGNAL(textChanged(const QString &)),this, SLOT(textChanged(const QString &)));
     connect(value, SIGNAL(returnPressed()), this, SLOT(ok_slot()));
 
     QHBoxLayout* hc = new QHBoxLayout( );
@@ -41,22 +50,11 @@ Search::Search(QWidget *parent, const char * name)
     hc->addWidget(wrap,1,AlignRight);
     wrap->setFixedSize(wrap->sizeHint());
 
-    hb = new KButtonBox( this, Horizontal, 6,6 );
-    vtop->addWidget(hb,0);
+    enableButton( User1, false );
 
-    ok = hb->addButton(i18n("Find"));
-    connect(ok, SIGNAL(clicked()), this, SLOT(ok_slot()));
+    connect(this, SIGNAL(user1Clicked()), this, SLOT(ok_slot()));
+    connect(this, SIGNAL(closeClicked()), this, SLOT(done_slot()));
 
-    hb->addStretch(1);
-
-    cancel = hb->addButton(i18n("Done"));
-    connect(cancel, SIGNAL(clicked()), this, SLOT(done_slot()));
-
-    hb->layout();
-    vf->activate();
-    vtop->activate();
-    resize(300, minimumSize().height());
-    setMaximumHeight(height());
     show();
 }
 
@@ -64,12 +62,18 @@ Search::~Search()
 {
 }
 
-void Search::ok_slot() 
+void Search::textChanged(const QString &text)
+{
+    enableButton( User1, !text.isEmpty() );
+}
+
+void Search::ok_slot()
 {
   QListViewItem *pkg;
 
-  QString to_find = this->value->text();
-  
+  QString to_find = value->text();
+  to_find = to_find.stripWhiteSpace();
+
   pkg = kpackage->management->search(to_find,
 		 substr->isChecked(),FALSE,FALSE);
   if (pkg == 0 && wrap->isChecked()) {
@@ -83,8 +87,7 @@ void Search::ok_slot()
 
 void Search::done_slot()
 {
-  this->hide();
-}
-void Search::resizeEvent(QResizeEvent *){
+  hide();
 }
 
+#include "search.moc"
