@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: slackInterface.cpp,v 1.31 2001/05/17 15:07:48 toivo Exp $
+//      $Id: slackInterface.cpp,v 1.37 2001/12/28 00:58:03 mueller Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -14,7 +14,7 @@
 #include <setjmp.h>
 
 #include <qdir.h>
-#include <qfileinf.h>
+#include <qfileinfo.h>
 #include <qregexp.h>
 
 #include <kurl.h>
@@ -40,7 +40,7 @@ enum {INITIAL, INSTALLED, UNINSTALLED};
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-SLACK::SLACK(QString remote):pkgInterface(remote)
+SLACK::SLACK():pkgInterface()
 {
   head = "SLACK";
   name = i18n("Slackware");
@@ -58,7 +58,7 @@ SLACK::SLACK(QString remote):pkgInterface(remote)
   queryMsg = i18n("Querying SLACK package list: ");
   procMsg = i18n("Kpackage: Waiting on SLACK");
 
-  locatedialog = new Locations(i18n("Location of Slackware package archives"));
+  locatedialog = new Locations(i18n("Location of Slackware Package Archives"));
   locatedialog->pLocations(1, 1, this,  i18n("I"),
   "Slackware", "*.TXT *.txt *.tgz *.tar.gz",
   i18n("Location of a 'PACKAGES.TXT' file for extended information"));
@@ -68,7 +68,7 @@ SLACK::SLACK(QString remote):pkgInterface(remote)
   i18n("Location of base directory of Slackware distribution"));
   locatedialog->dLocations(2, 6, this,  i18n("D"),
   "Slackware", "*.tgz *.tar.gz",
-  i18n("Location of directories containg Slackware packages"));
+  i18n("Location of directories containing Slackware packages"));
 
   connect(locatedialog,SIGNAL(returnVal(LcacheObj *)),
   	  this,SLOT(setAvail(LcacheObj *)));
@@ -130,7 +130,7 @@ bool SLACK::parseName(QString name, QString *n, QString *v)
   return FALSE;
 }
 
-void SLACK::listPackages(QList<packageInfo> *pki)
+void SLACK::listPackages(QPtrList<packageInfo> *pki)
 {
   QString s;
   cacheObj *cp;
@@ -168,7 +168,7 @@ void SLACK::listPackages(QList<packageInfo> *pki)
   }
 }
 
-void SLACK::listInstalledPackages(QList<packageInfo> *pki)
+void SLACK::listInstalledPackages(QPtrList<packageInfo> *pki)
 {
   FILE *file;
   char linebuf[1024];
@@ -222,7 +222,7 @@ void SLACK::listInstalledPackages(QList<packageInfo> *pki)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-void SLACK::listPackList(QList<packageInfo> *pki, QString s,  cacheObj *cp, int insState)
+void SLACK::listPackList(QPtrList<packageInfo> *pki, QString s,  cacheObj *cp, int insState)
 {
   int np;
   QString vb;
@@ -507,7 +507,7 @@ QStringList SLACK::getFileList(packageInfo *p)
       // query an uninstalled package
     case 'u':
            name = fn;
-	   
+
 	   QString s = "sh -c 'cat ";
 	   s += fn;
 	   s += "|gunzip |tar -t -f -'";
@@ -538,18 +538,19 @@ QString SLACK::doUninstall(int uninstallFlags, QString packs, bool &)
 // Call the script to install packages setting parameters
 // to slack dependent on flags, returning whether everyting worked
 //////////////////////////////////////////////////////////////////////////////
-QString SLACK::install(int installFlags, QList<packageInfo> *plist, bool &test)
+QString SLACK::install(int installFlags, QPtrList<packageInfo> *plist, bool &test)
 {
   packageInfo *pk;
   int i = 0;
+  QString packs = "";
   for (pk = plist->first(); pk != 0; pk = plist->next()) {
     QString fname = pk->fetchFilename();
     if (fname != "") {
-      doInstall(installFlags, fname, test);
+      packs += fname + " ";
       i++;
     }
   }
-  return 0;
+  return doInstall(installFlags, packs, test);
 }
 
 QString SLACK::doInstall(int installFlags, QString packs, bool &)
