@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: slackInterface.h,v 1.17 2001/04/03 16:17:53 toivo Exp $ 
+//      $Id: slackInterface.h,v 1.19 2001/09/26 16:33:31 mlaurent Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -10,7 +10,7 @@
 
 #include "../config.h"
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kprocess.h>
 
 #include "pkgInterface.h"
@@ -24,7 +24,7 @@ class SLACK: public pkgInterface
   Q_OBJECT
 
 public:
-  SLACK(QString remote);
+  SLACK();
   ~SLACK();
   
   bool isType(char *buf, const QString &fname);
@@ -36,7 +36,7 @@ public:
   QStringList FindFile(const QString &name);
   bool parseName(QString name, QString *n, QString *v);
 
-  QString install(int installFlags, QList<packageInfo> *plist, bool &test);
+  QString install(int installFlags, QPtrList<packageInfo> *plist, bool &test);
 
 public slots:
   void setLocation();
@@ -44,13 +44,13 @@ public slots:
 
 private:
   packageInfo* collectInfo(const char *inp, int insState);
-   void listInstalledPackages(QList<packageInfo> *pki);
+   void listInstalledPackages(QPtrList<packageInfo> *pki);
  
   QString doUninstall(int installFlags, QString packs, bool &test);
   QString doInstall(int installFlags, QString packs, bool &test);
 
-  void listPackages(QList<packageInfo> *pki);
-  void listPackList(QList<packageInfo> *pki, QString s,
+  void listPackages(QPtrList<packageInfo> *pki);
+  void listPackList(QPtrList<packageInfo> *pki, QString s,
 		    cacheObj *cp, int insState);
 
   void initTranslate();
