@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: updateLoc.h,v 1.15 2000/09/01 20:19:46 waba Exp $ 
+//      $Id: updateLoc.h,v 1.16 2001/05/30 20:27:15 waba Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -17,18 +17,14 @@
 #include <qframe.h>
 #include <qlabel.h>
 #include <qfiledlg.h> 
-#include <qgrpbox.h> 
-#include <qchkbox.h>
+#include <qgroupbox.h> 
+#include <qcheckbox.h>
 #include <qlayout.h> 
-#include <qlined.h>
-#include <qtabdlg.h>
+#include <qlineedit.h>
 
 // KDE headers
-#include <kapp.h>
-#include <kmenubar.h>
-//#include <kmsgbox.h>
-#include <kbuttonbox.h> 
-#include <kfiledialog.h> 
+#include <kbuttonbox.h>
+#include <kdialogbase.h>
 
 class pkgInterface;
 class updateLoc;
@@ -74,7 +70,7 @@ private:
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-class updateLoc : public QDialog
+class updateLoc : public QWidget
 {
   Q_OBJECT
 
@@ -85,9 +81,6 @@ public:
 	     QString lmsg, QString bmsg = 0, bool subdirs = FALSE);
   ~updateLoc(); 
 
-  void restore();
-  // show window, setting the buttons
-
   void readSettings();
   void writeSettings();
 
@@ -126,7 +119,7 @@ private:
 };
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-class Locations : public QDialog
+class Locations : public KDialogBase
 {
   Q_OBJECT
 
@@ -152,7 +145,6 @@ void cLocations(int numberDirs, int numberLines,
 ~Locations();
 void restore();
 
-QTabDialog *tab;
 int numPanels;
 static const int PANNUM = 10;
 updateLoc *pn[PANNUM];
