@@ -2,10 +2,7 @@
 #define RUNLEVEL_AUTH_ICON_H
 
 // (c) 2000 Peter Putzer <putzer@kde.org>
-#pragma interface
-
 #include <kauthicon.h>
-#include "Constants.h"
 
 class QTimer;
 class QFileInfo;
@@ -14,7 +11,7 @@ class RunlevelAuthIcon : public KAuthIcon
 {
   Q_OBJECT
   Q_PROPERTY (int refreshInterval READ refreshInterval WRITE setRefreshInterval)
-
+    
 public:
   RunlevelAuthIcon (const QString& scriptPath, const QString& runlevelPath,
 					QWidget* parent = 0L, const char* name = 0L);
@@ -24,24 +21,29 @@ public:
   virtual bool status () const;
 
   inline int refreshInterval () const { return mInterval; }
+  inline bool isCheckEnabled () const { return mCheckEnabled; }
 
 public slots:
   virtual void updateStatus ();
 
-  void setScriptPath (const QString& scriptPath);
+  void setServicesPath (const QString& servicesPath);
   void setRunlevelPath (const QString& runlevelPath);
 
   void setRefreshInterval (int);
 
+  void setCheckEnabled(bool);
+
 private slots:
   void timerEvent ();
 
 private:
   QTimer* mTimer;
-  QFileInfo* mScriptInfo;
-  QFileInfo* mRLInfo [RUNLEVEL_NR];
+  QFileInfo* mServicesInfo;
+  QFileInfo** mRLInfo;
   bool mOld;
   int mInterval;
+  
+  bool mCheckEnabled;
 };
 
 #endif // RUNLEVEL_AUTH_ICON_H
