@@ -1,4 +1,4 @@
-/***************************************************************************
+ /***************************************************************************
                           main.cpp  -  description
                              -------------------
     copyright            : (C) 1997-2000 by Peter Putzer
@@ -16,7 +16,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <iostream>
+#include <iostream.h>
 
 #include <qvariant.h>
 
@@ -24,10 +24,12 @@
 #include <kaboutdata.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "ksvapplication.h"
 #include "ksv_core.h"
+#include "ksv_conf.h"
+#include "ksvconfigwizard.h"
 #include "TopWidget.h"
 
 // copyright notice
@@ -53,7 +55,7 @@ void myMessageOutput( QtMsgType type, const char *msg )
   case QtFatalMsg:
     cerr << "Fatal: " << msg << endl;
     abort(); // dump core on purpose
-  }	
+  }
 }
 
 int main( int argc, char **argv ) {
@@ -89,11 +91,23 @@ int main( int argc, char **argv ) {
   // session-management
   if (kapp->isRestored())
 	RESTORE(KSVTopLevel)
-      else
+  else
+    {
+      KSVConfig* conf = KSVConfig::self();
+      if (!conf->isConfigured())
         {
-          KSVTopLevel* top = new KSVTopLevel();
-          top->show();
+          KSVConfigWizard* w = new KSVConfigWizard(0, "ConfigWizard", true);
+          w->exec();
+
+          conf->setConfigured(true);
+          conf->setRunlevelPath (w->runlevelPath());
+          conf->setScriptPath (w->servicesPath());
+          conf->writeSettings();
         }
+
+      KSVTopLevel* top = new KSVTopLevel();
+      top->show();
+    }
   // end session-management
 
   returnValue = app.exec();
