@@ -26,7 +26,7 @@
 #include <signal.h>
 #endif
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
 #include <shadow.h>
 #endif
 
@@ -36,6 +36,9 @@
 #include "kglobal_.h"
 #include "kuser.h"
 #include "misc.h"
+#include <kstandarddirs.h>
+#include <kmessagebox.h>
+#include "editDefaults.h"	
 
 #ifdef _KU_QUOTA
 #include "mnt.h"
@@ -60,19 +63,19 @@ KUser::KUser() : p_pwd("*") {
   p_uid     = 0;
   p_gid     = 100;
 
-#ifdef _KU_SHADOW   
+#ifdef HAVE_SHADOW   
   s_lstchg  = 0;
   s_min     = 0;
-  s_max     = -1;
+  s_max     = 99999;
   s_warn    = 7;
   s_inact   = -1;
-  s_expire  = 99999;
-  s_flag    = 0;
+  s_expire  = -1;
+//  s_flag    = 0;
 #endif
 
-  isCreateHome = 0;
-  isCreateMailBox = 0;
-  isCopySkel = 0;
+  isCreateHome = false;
+  isCreateMailBox = false;
+  isCopySkel = false;
 }
   
 KUser::KUser(const KUser *user) {
@@ -100,7 +103,7 @@ void KUser::copy(const KUser *user) {
   p_uid     = user->p_uid;
   p_gid     = user->p_gid;
 
-#ifdef _KU_SHADOW   
+#ifdef HAVE_SHADOW   
   s_pwd = user->s_pwd;
   s_lstchg  = user->s_lstchg;
   s_min     = user->s_min;
@@ -119,15 +122,15 @@ void KUser::copy(const KUser *user) {
 KUser::~KUser() {
 }
 
-int KUser::getCreateHome() {
+bool KUser::getCreateHome() {
   return isCreateHome;
 }
 
-int KUser::getCreateMailBox() {
+bool KUser::getCreateMailBox() {
   return isCreateMailBox;
 }
 
-int KUser::getCopySkel() {
+bool KUser::getCopySkel() {
   return isCopySkel;
 }
 
@@ -203,7 +206,7 @@ gid_t KUser::getGID() const {
   return p_gid;
 }
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
 const QString &KUser::getSPwd() const {
   return s_pwd;
 }
@@ -309,7 +312,7 @@ void KUser::setGID(gid_t data) {
   p_gid = data;
 }
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
 void KUser::setSPwd(const QString &data) {
   s_pwd = data;
 }
@@ -344,20 +347,21 @@ void KUser::setFlag(int data) {
 
 #endif
 
-void KUser::setCreateHome(int data) {
+void KUser::setCreateHome(bool data) {
   isCreateHome = data;
 }
 
-void KUser::setCreateMailBox(int data) {
+void KUser::setCreateMailBox(bool data) {
   isCreateMailBox = data;
 }
 
-void KUser::setCopySkel(int data) {
+void KUser::setCopySkel(bool data) {
   isCopySkel = data;
 }
 
 KUsers::KUsers() {
-  p_backuped = FALSE;
+  pw_backuped = FALSE;		
+  pn_backuped = FALSE;		
   s_backuped = FALSE;
 
   pwd_mode = 0644;
@@ -423,64 +427,128 @@ bool KUsers::load() {
 bool KUsers::loadpwd() {
   passwd *p;
   KUser *tmpKU = 0;
-
-  // Start reading passwd file
-
   struct stat st;
+  QString filename;				
+  QString passwd_filename;			
+  QString nispasswd_filename;			
+  int rc = 0;					
+  int passwd_errno = 0;				
+  int nispasswd_errno = 0;			
+  char processing_file = '\0';			
+  #define PASSWD    0x01			
+  #define NISPASSWD 0x02			
+  #define MAXFILES 2
 
-  stat(PASSWORD_FILE, &st);
-  pwd_mode = st.st_mode & 0666;
-  pwd_uid = st.st_uid;
-  pwd_gid = st.st_gid;
+  // Read KUser configuration	
 
-  // We are reading our PASSWORD_FILE
-  QString tmp;
-#ifdef HAVE_FGETPWENT
-  FILE *fpwd = fopen(PASSWORD_FILE, "r");
-  if(fpwd == NULL) {
-     err->addMsg(i18n("Error opening %1 for reading").arg(PASSWORD_FILE));
-     return FALSE;
+  config->setGroup("sources");		
+  passwd_filename = config->readEntry("passwdsrc");	
+  nispasswd_filename = config->readEntry("nispasswdsrc");	
+
+  // Handle unconfigured environments
+
+  if(passwd_filename.isEmpty() && nispasswd_filename.isEmpty()) {
+    config->writeEntry("passwdsrc", PASSWORD_FILE);
+    config->writeEntry("groupsrc", GROUP_FILE);
+    passwd_filename = config->readEntry("passwdsrc");	
+    err->addMsg(i18n("KUser Sources were not configured.\nLocal passwd source set to %1\nLocal group source set to %2\n").arg(config->readEntry("passwdsrc")).arg(config->readEntry("groupsrc")));
+    err->display();
   }
 
-  while ((p = fgetpwent(fpwd)) != NULL) {
+  if(!passwd_filename.isEmpty()) {			
+    processing_file = processing_file | PASSWD;		
+    filename.append(passwd_filename);			
+  }
+
+  // Start reading passwd file(s)
+
+  for(int i = 0; i < MAXFILES; i++) {
+    rc = stat(QFile::encodeName(filename), &st);		
+    if(rc != 0) {						
+      err->addMsg(i18n("stat call on file %1 failed: %2\nCheck KUser Settings (Sources)\n").arg(filename).arg(strerror(errno)));	
+      err->display();						
+      if( (processing_file & PASSWD) != 0 ) {			
+        passwd_errno = errno;					
+        if(!nispasswd_filename.isEmpty()) {			
+          processing_file = processing_file & ~PASSWD;		
+          processing_file = processing_file | NISPASSWD;	
+          filename.truncate(0);					
+          filename.append(nispasswd_filename);	
+        } 
+        continue;				
+      }						
+      else{					
+        nispasswd_errno = errno;					
+        break;					
+      }
+    }						
+
+    pwd_mode = st.st_mode & 0666;
+    pwd_uid = st.st_uid;
+    pwd_gid = st.st_gid;
+
+    // We are reading our configuration specified passwd file
+    QString tmp;
+#ifdef HAVE_FGETPWENT
+    FILE *fpwd = fopen(QFile::encodeName(filename), "r");		
+    if(fpwd == NULL) {
+      err->addMsg(i18n("Error opening %1 for reading").arg(filename));	
+      return FALSE;
+    }
+
+    while ((p = fgetpwent(fpwd)) != NULL) {
 #else
-  while ((p = getpwent()) != NULL) {
+    while ((p = getpwent()) != NULL) {
 #endif
 #ifdef _KU_QUOTA
-    kug->getQuotas().addQuota(p->pw_uid);
+      kug->getQuotas().addQuota(p->pw_uid);
 #endif
-    tmpKU = new KUser();
-    tmpKU->setUID(p->pw_uid);
-    tmpKU->setGID(p->pw_gid);
-    tmpKU->setName(p->pw_name);
-    tmpKU->setPwd(p->pw_passwd);
-    tmpKU->setHomeDir(p->pw_dir);
-    tmpKU->setShell(p->pw_shell);
+      tmpKU = new KUser();
+      tmpKU->setUID(p->pw_uid);
+      tmpKU->setGID(p->pw_gid);
+      tmpKU->setName(p->pw_name);
+      tmpKU->setPwd(p->pw_passwd);
+      tmpKU->setHomeDir(p->pw_dir);
+      tmpKU->setShell(p->pw_shell);
 #if defined(__FreeBSD__) || defined(__bsdi__)
-    tmpKU->setClass(p->pw_class);
-    tmpKU->setLastChange(p->pw_change);
-    tmpKU->setExpire(p->pw_expire);
+      tmpKU->setClass(p->pw_class);
+      tmpKU->setLastChange(p->pw_change);
+      tmpKU->setExpire(p->pw_expire);
 #endif
 
-    if ((p->pw_gecos != 0) && (p->pw_gecos[0] != 0))
-      fillGecos(tmpKU, p->pw_gecos);
+      if ((p->pw_gecos != 0) && (p->pw_gecos[0] != 0)) 
+        fillGecos(tmpKU, p->pw_gecos);
+      u.append(tmpKU);
+    }
 
-    u.append(tmpKU);
-  }
-
-  // End reading passwd file
+    // End reading passwd_filename				
 
 #ifdef HAVE_FGETPWENT
-  fclose(fpwd);
+    fclose(fpwd);
 #endif
+    if((!nispasswd_filename.isEmpty()) && (nispasswd_filename != passwd_filename)) {
+      processing_file = processing_file & ~PASSWD;
+      processing_file = processing_file | NISPASSWD;		
+      filename.truncate(0);				
+      filename.append(nispasswd_filename);		
+    } 
+    else						
+      break;						
 
-  return (TRUE);
+  }	// end of processing files, for loop			
+
+  if( (passwd_errno == 0) && (nispasswd_errno == 0) )	
+    return (TRUE);
+  if( (passwd_errno != 0) && (nispasswd_errno != 0) )	
+    return (FALSE);
+  else
+    return(TRUE);						
 }
 
 // Load shadow passwords
 
 bool KUsers::loadsdw() {
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
   QString tmp;
   struct spwd *spw;
   KUser *up = NULL;
@@ -527,7 +595,7 @@ bool KUsers::loadsdw() {
   }
 
   endspent();
-#endif // _KU_SHADOW
+#endif // HAVE_SHADOW
   return TRUE;
 }
 
@@ -548,38 +616,52 @@ bool KUsers::save() {
 }
 
 bool KUsers::doCreate() {
+
+  QString h_dir;
+
   for (unsigned int i=0; i<u.count(); i++) {
     KUser *user = u.at(i);
 
     if(user->getCreateMailBox()) {
       user->createMailBox();
-      user->setCreateMailBox(0);
+      user->setCreateMailBox(false);
     }
 
     if(user->getCreateHome()) {
-       user->createHome();
-       user->setCreateHome(0);
+       if(user->createHome()) {
+           user->setCreateHome(false);
+           if(!user->getCopySkel())
+       	       user->createKDE();
+       }
+       else
+	  continue;	// if createHome fails, copySkel is irrelevant!
     }
 
     if(user->getCopySkel()) {
-       user->copySkel();
-       user->setCopySkel(0);
+       if((user->copySkel()) == 0) {
+          user->setCopySkel(false);
+       	  h_dir = user->getHomeDir();
+          if(!user->findKDE(h_dir))
+             user->createKDE();
+       }
     }
-  }
 
+  }
   return TRUE;
 }
 
 bool KUsers::doDelete() {
-  for (unsigned int i=0; i<du.count(); i++) {
-    KUser *user = du.at(i);
+	uint ucnt = du.count();
+  KUser *user;
 
+  user = du.first();
+  for (unsigned int i=0; i<ucnt; i++) {
+    user = du.current(); 
     user->removeHome();
     user->removeCrontabs();
     user->removeMailBox();
     user->removeProcesses();
-
-    du.remove(i);
+    du.remove();
   }
 
   return TRUE;
@@ -588,29 +670,73 @@ bool KUsers::doDelete() {
 // Save password file
 
 bool KUsers::savepwd() {
-  FILE *passwd;
+  FILE *passwd_fd = NULL;			
+  FILE *nispasswd_fd = NULL;			
+  int minuid = 0;			
+  int nis_users_written = 0;		
+  uid_t tmp_uid = 0;			
   QString s;
   QString s1;
-
   QString tmp;
+  QString passwd_filename;		
+  QString nispasswd_filename;
+  QString qs_minuid;			
 
-  if (!p_backuped) {
-    backup(PASSWORD_FILE);
-    p_backuped = TRUE;
+  const char *c_minuid;			
+  const char *pw_filename;		
+  const char *pn_filename;		
+  char errors_found = '\0';		
+    #define NOMINUID    0x01		
+    #define NONISPASSWD 0x02		
+
+  // Read KUser configuration info	
+
+  config->setGroup("sources");		
+  passwd_filename = config->readEntry("passwdsrc");		
+  nispasswd_filename = config->readEntry("nispasswdsrc");	
+  qs_minuid = config->readEntry("nisminuid");			
+  if( (!qs_minuid.isEmpty()) && (nispasswd_filename != passwd_filename) ) {
+    c_minuid = qs_minuid.latin1();				
+    minuid = atoi(c_minuid);		
   }
 
-  umask(0077);
+  // Backup file(s)			
 
-  if ((passwd = fopen(PASSWORD_FILE,"w")) == NULL) {
-    err->addMsg(i18n("Error opening %1 for writing").arg(PASSWORD_FILE));
-    return FALSE;
+  if(!passwd_filename.isEmpty()) {	
+    if (!pw_backuped) {			
+      pw_filename = passwd_filename.latin1();   
+      backup(pw_filename);		
+      pw_backuped = TRUE;		
+    }
+  }
+  if(!nispasswd_filename.isEmpty() && (nispasswd_filename != passwd_filename)){	
+    if (!pn_backuped) {			
+      pn_filename = nispasswd_filename.latin1();   
+      backup(pn_filename);		
+      pn_backuped = TRUE;		
+    }
   }
 
-  for (unsigned int i=0; i<u.count(); i++) {
-    KUser *user = u.at(i);
+  // Open file(s)			
+
+  if(!passwd_filename.isEmpty()) {	
+    if ((passwd_fd = fopen(QFile::encodeName(passwd_filename),"w")) == NULL) 
+      err->addMsg(i18n("Error opening %1 for writing").arg(passwd_filename));
+  }					
+
+  if(!nispasswd_filename.isEmpty() && (nispasswd_filename != passwd_filename)){	
+    if ((nispasswd_fd = fopen(QFile::encodeName(nispasswd_filename),"w")) == NULL) 
+      err->addMsg(i18n("Error opening %1 for writing").arg(nispasswd_filename));
+  }					
+
+    umask(0077);
+
+    for (unsigned int i=0; i<u.count(); i++) {
+      KUser *user = u.at(i);
+      tmp_uid = user->getUID();	 	
 
 #if defined(__FreeBSD__) || defined(__bsdi__)
-    s = QString("%1:%2:%3:%4:%5:%6:%7:")
+      s = QString("%1:%2:%3:%4:%5:%6:%7:")
         .arg(user->getName())
         .arg(user->getPwd())
 	.arg(user->getUID())
@@ -619,20 +745,20 @@ bool KUsers::savepwd() {
         .arg(user->getLastChange())
 	.arg(user->getExpire());
 
-    s1 = QString("%1,%2,%3,%4")
+      s1 = QString("%1,%2,%3,%4")
          .arg(user->getFullName())
          .arg(user->getOffice())
          .arg(user->getWorkPhone())
          .arg(user->getHomePhone());
 #else
 
-    s = QString("%1:%2:%3:%4:")
+      s = QString("%1:%2:%3:%4:")
         .arg(user->getName())
         .arg(user->getPwd())
 	.arg(user->getUID())
         .arg(user->getGID());
 
-    s1 = QString("%1,%2,%3,%4")
+      s1 = QString("%1,%2,%3,%4")
          .arg(user->getFullName())
 	 .arg(user->getOffice1())
 	 .arg(user->getOffice2())
@@ -640,28 +766,79 @@ bool KUsers::savepwd() {
 
 #endif
 
-    for (int j=(s1.length()-1); j>=0; j--) {
-      if (s1[j] != ',')
-        break;
+      for (int j=(s1.length()-1); j>=0; j--) {
+        if (s1[j] != ',')
+          break;
 
-      s1.truncate(j);
-    }
+        s1.truncate(j);
+      }
 
-    s += s1+":"+user->getHomeDir()+":"+user->getShell()+"\n";
-    fputs(QFile::encodeName(s), passwd);
-  }
-  fclose(passwd);
+      s += s1+":"+user->getHomeDir()+":"+user->getShell()+"\n";
 
-  chmod(PASSWORD_FILE, pwd_mode);
-  chown(PASSWORD_FILE, pwd_uid, pwd_gid);
+      if( (nispasswd_fd != 0) && (minuid != 0) ) {
+        if (minuid <= tmp_uid) {
+      	  fputs(QFile::encodeName(s), nispasswd_fd);	
+          nis_users_written++;		
+          continue;				
+        }
+        else{
+      	  fputs(QFile::encodeName(s), passwd_fd);	
+          continue;				
+        }
+      }
+
+      if( (nispasswd_fd != 0) && (minuid == 0) ) {
+	errors_found = errors_found | NOMINUID;  
+      	fputs(QFile::encodeName(s), passwd_fd);	
+        continue;
+      }
+
+      if( (nispasswd_fd == 0) && (minuid != 0) ) {
+	errors_found = errors_found | NONISPASSWD;	
+      	fputs(QFile::encodeName(s), passwd_fd);	
+        continue;
+      }
+
+      fputs(QFile::encodeName(s), passwd_fd);	
+
+    }		/* end for i loop */
+
+    if(passwd_fd) {					
+      fclose(passwd_fd);
+      chmod(QFile::encodeName(passwd_filename), pwd_mode);	
+      chown(QFile::encodeName(passwd_filename), pwd_uid, pwd_gid);	
+    }							
+
+    if(nispasswd_fd) {					
+      fclose(nispasswd_fd);				
+      chmod(QFile::encodeName(nispasswd_filename), pwd_mode);	
+      chown(QFile::encodeName(nispasswd_filename), pwd_uid, pwd_gid);	
+    }							
+
+    if( (errors_found & NOMINUID) != 0 ) {	
+      err->addMsg(i18n("Unable to process NIS passwd file without a minimum UID specified.\nPlease update KUser Settings (Sources)"));	
+      err->display();				
+    }						
+
+    if( (errors_found & NONISPASSWD) != 0 ) {
+      err->addMsg(i18n("Specifying NIS minimum UID requires NIS file(s).\nPlease update KUser Settings (Sources)"));	
+      err->display();				
+    }						
 
-#ifdef PWMKDB
   // need to run a utility program to build /etc/passwd, /etc/pwd.db
   // and /etc/spwd.db from /etc/master.passwd
+#if defined(__FreeBSD__) || defined(__bsdi__)
   if (system(PWMKDB) != 0) {
-     err->addMsg(i18n("Unable to build password database"));
-     return FALSE;
+    err->addMsg(i18n("Unable to build password database"));
+    return FALSE;
   }
+#else
+  if( (nis_users_written > 0) || (nispasswd_filename == passwd_filename) ) {
+    if (system(PWMKDB) != 0) {
+      err->addMsg(i18n("Unable to build password databases"));
+      return FALSE;
+    }
+  }					
 #endif
 
   return TRUE;
@@ -670,7 +847,7 @@ bool KUsers::savepwd() {
 // Save shadow passwords file
 
 bool KUsers::savesdw() {
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
   QString tmp;
   FILE *f;
   struct spwd *spwp;
@@ -723,7 +900,7 @@ bool KUsers::savesdw() {
 
   free(s.sp_namp);
   free(s.sp_pwdp);
-#endif // _KU_SHADOW
+#endif // HAVE_SHADOW
   return TRUE;
 }
 
@@ -748,7 +925,7 @@ uid_t KUsers::first_free() {
     if (lookup(t) == NULL)
       return t;
 
-  err->addMsg(i18n("You have more than 65534 users!?!? You have ran out of uid space!"));
+  err->addMsg(i18n("You have more than 65534 users!?!? You have run out of uid space!"));
   return (-1);
 }
 
@@ -783,31 +960,174 @@ void KUsers::del(KUser *au) {
   u.remove(au);
 }
 
-void KUser::createHome() {
-  QDir d = QDir::root();
+int KUser::createHome() {
 
-  if (d.cd(p_dir)) {
-    err->addMsg(i18n("Directory %1 already exists").arg(p_dir));
+  if(p_dir.isNull() || p_dir.isEmpty()) {
+    err->addMsg(i18n("Cannot create home directory for %1: it is null or empty\n").arg(p_name));
     err->display();
+    return(0);
   }
-
   if (mkdir(QFile::encodeName(p_dir), 0700) != 0) {
-    err->addMsg(i18n("Cannot create home directory\nError: %1").arg(QString::fromLocal8Bit(strerror(errno))));
+    err->addMsg(i18n("Cannot create home directory %1\nError: %2").arg(p_dir).arg(QString::fromLocal8Bit(strerror(errno))));
     err->display();
-    return;
+    return(0);
   }
 
   if (chown(QFile::encodeName(p_dir), p_uid, p_gid) != 0) {
-    err->addMsg(i18n("Cannot change owner of home directory\nError: %1").arg(QString::fromLocal8Bit(strerror(errno))));
+    err->addMsg(i18n("Cannot change owner of home directory %1\nError: %2").arg(p_dir).arg(QString::fromLocal8Bit(strerror(errno))));
     err->display();
-    return;
+    return(1);
   }
 
   if (chmod(QFile::encodeName(p_dir), KU_HOMEDIR_PERM) != 0) {
-    err->addMsg(i18n("Cannot change permissions on home directory\nError: %1").arg(QString::fromLocal8Bit(strerror(errno))));
+    err->addMsg(i18n("Cannot change permissions on home directory %1\nError: %2").arg(p_dir).arg(QString::fromLocal8Bit(strerror(errno))));
     err->display();
-    return;
+    return(1);
   }
+  return(1);
+}
+
+int KUser::createKDE() {
+
+	QStringList levels;	
+	QStringList types;		
+	QString k_dir = p_dir;
+	KStandardDirs kstddirs;
+	const char *KDEHOME = "KDEHOME";
+	const char *DOT_KDE = "/.kde";
+	const char *kdehome;
+	const char *dot_kde = NULL;
+
+
+	if((kdehome = getenv(KDEHOME)) != NULL) {
+	    dot_kde = strstr(kdehome,DOT_KDE);
+	    if(dot_kde) {
+	        levels.append(dot_kde);	
+	        levels.append("/share");	
+	        levels.append("/doc");	
+	    }
+	    else {
+	        levels.append("/.kde");	
+	        levels.append("/share");	
+	        levels.append("/doc");	
+	    }
+	}
+	else {
+	    levels.append("/.kde");	
+	    levels.append("/share");	
+	    levels.append("/doc");	
+	}
+
+	for (uint level=0; level<levels.count(); level++) {
+		k_dir.append(levels[level]);	
+		if (tryCreate(k_dir))
+			return(-1);
+ 	}
+
+	types = kstddirs.KStandardDirs::allTypes();
+
+	for(uint i=0; i<types.count(); i++) {
+		k_dir = p_dir;
+		k_dir.append(levels[0]);
+		// if(dot_kde)
+		k_dir.append("/");
+		const char *ctype = types[i].latin1();
+		QString tpath = KStandardDirs::kde_default(ctype);
+		k_dir.append(tpath);
+		if (tryCreate(k_dir))
+			return(-1);
+	}
+
+  return(0);
+
+}
+
+int KUser::tryCreate(const QString &dir) {
+struct stat sb;
+int	rc = 0;
+
+    rc = stat(QFile::encodeName(dir), &sb);
+    if (rc == 0) {
+   	if (S_ISDIR(sb.st_mode)) {
+	    if (KMessageBox::
+		warningContinueCancel(0, i18n("Directory %1 already exists!\nWill make %2 owner and change permissions.\nDo you want to continue?")
+.arg(dir).arg(p_name), QString::null, i18n("&Continue")) ==
+KMessageBox::Continue) {
+ 		if (chown(QFile::encodeName(dir), p_uid, p_gid) != 0) {
+   		    err->addMsg(i18n("Cannot change owner of %1 directory\nError: %2")
+.arg(dir).arg(strerror(errno)));
+		    err->display();
+ 		}
+	  	if (chmod(QFile::encodeName(dir), KU_KDEDIRS_PERM) != 0) {
+   			err->addMsg(i18n("Cannot change permissions on %1 directory\nError: %2").arg(dir).arg(strerror(errno)));
+   			err->display();
+ 		}
+			return(0);
+			}
+	    else {
+   		err->addMsg(i18n("Directory %1 left 'as is'.\nVerify ownership and permissions for user %2 who may not be able to log in!").arg(dir).arg(p_name));
+   		err->display();
+		return(-1);
+	    }
+	}
+	else {
+   	    err->addMsg(i18n("%1 exists and is not a directory. User %2 will not be able to log in!").arg(dir).arg(p_name));
+   	    err->display();
+	    return(-1);
+	}
+    }
+    else {
+	if (errno == ENOENT) {
+ 	    if (mkdir(QFile::encodeName(dir), 0700) != 0) {
+   		err->addMsg(i18n("Cannot create %1 directory\nError: %2").arg(dir)
+		    .arg(strerror(errno)));
+   		err->display();
+		return(-1);
+  	    }
+	    if (chown(QFile::encodeName(dir), p_uid, p_gid) != 0) {
+   		err->addMsg(i18n("Cannot change owner of %1 directory\nError: %2")
+		    .arg(dir).arg(strerror(errno)));
+   		err->display();
+ 	    }
+	    if (chmod(QFile::encodeName(dir), KU_KDEDIRS_PERM) != 0) {
+   		err->addMsg(i18n("Cannot change permissions on %1 directory\nError: %2").arg(dir).arg(strerror(errno)));
+		err->display();
+ 	    }
+	    return(0);
+ 	}
+	else {
+   	    err->addMsg(i18n("stat call on %1 failed.\nError: %2").arg(dir)
+		.arg(strerror(errno)));
+	    err->display();
+	    return(-1);
+	}
+    }
+}
+
+bool KUser::findKDE(const QString &dir) {
+   int		kde_count     = 0;
+   const QFileInfo	*fi   = NULL;
+   const QFileInfoList	*list = NULL;
+   QDir		t(dir);
+   QString	dot_KDE = ".kde";
+   bool		foundKDE;
+
+   foundKDE = false;
+   t.setFilter( QDir::Dirs | QDir::Hidden );
+   list = t.entryInfoList();
+   QFileInfoListIterator it( *list );
+
+   while ( (fi = it.current()) != 0 ) {
+      kde_count = fi->fileName().contains(dot_KDE, TRUE);
+      if(kde_count > 0)
+      foundKDE = true;
+      ++it;
+   }
+
+   if(foundKDE)
+	return TRUE;
+   else
+	return FALSE;
 }
 
 int KUser::createMailBox() {
@@ -849,7 +1169,7 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath) {
   QString prefix(SKEL_FILE_PREFIX);
   int len = prefix.length();
 
-  s.setFilter(QDir::Dirs);
+  s.setFilter(QDir::Dirs | QDir::Hidden);
 
   for (uint i=0; i<s.count(); i++) {
     QString name(s[i]);
@@ -869,6 +1189,7 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath) {
       name = name.remove(0, len);
 
     d.mkdir(name, FALSE);
+
     if (chown(QFile::encodeName(d.filePath(name)), p_uid, p_gid) != 0) {
       err->addMsg(i18n("Cannot change owner of directory %1\nError: %2")
                   .arg(d.filePath(s[i])).arg(QString::fromLocal8Bit(strerror(errno))));
@@ -897,7 +1218,6 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath) {
       name = name.remove(0, len);
 
     if (copyFile(filename, d.filePath(name)) == -1) {
-      err->display();
       continue;
     }
 
@@ -922,13 +1242,13 @@ int KUser::copySkel() {
   umask(0777);
 
   if (!s.exists()) {
-    err->addMsg(i18n("Directory %1 does not exist").arg(s.dirName()));
+    err->addMsg(i18n("Directory %1 does not exist, cannot copy skeleton for %2").arg(s.absPath()).arg(p_name));
     err->display();
     return (-1);
   }
 
   if (!d.exists()) {
-    err->addMsg(i18n("Directory %1 does not exist").arg(d.dirName()));
+    err->addMsg(i18n("Directory %1 does not exist, cannot copy skeleton").arg(d.absPath()));
     err->display();
     return (-1);
   }
@@ -953,12 +1273,20 @@ int KUser::removeHome() {
 #else
       command = QString("/bin/rm -rf -- %1").arg(p_dir);
 #endif
-    if (system(QFile::encodeName(command)) != 0) {
-      err->addMsg(i18n("Cannot remove home directory %1\nError: %2")
-                  .arg(command).arg(QString::fromLocal8Bit(strerror(errno))));
+      if (system(QFile::encodeName(command)) != 0) {
+             err->addMsg(i18n("Cannot remove home directory %1\nError: %2")
+                       .arg(command).arg(strerror(errno)));
+             err->display();
+      }
+    } else {
+      err->addMsg(i18n("Removal of home directory %1 failed (uid = %2, gid = %3)").arg(p_dir).arg(sb.st_uid).arg(sb.st_gid));
       err->display();
-     }
-   }
+    }
+  else {
+    err->addMsg(i18n("stat call on file %1 failed\nError: %2")
+                 .arg(p_dir).arg(strerror(errno)));
+    err->display();
+  }
 
   return 0;
 }
