@@ -16,6 +16,7 @@ mainWidget::mainWidget(const char *name) : KMainWindow(0,name) {
   md = new mainView(this);
 
   setupActions();
+  md->slotTabChanged();
 
   sbar = new KStatusBar(this);
   sbar->insertItem("Reading config", 0);
@@ -27,12 +28,10 @@ mainWidget::mainWidget(const char *name) : KMainWindow(0,name) {
   sbar->changeItem(i18n("Ready"), 0);
 }
 
-mainWidget::~mainWidget() {
-  if (md)
-    delete md;
-
-  if (sbar)
-    delete sbar;
+mainWidget::~mainWidget() 
+{
+  delete md;
+  delete sbar;
 }
 
 void mainWidget::setupActions() {
@@ -44,21 +43,32 @@ void mainWidget::setupActions() {
   mActionStatusbar = KStdAction::showStatusbar(this, SLOT(toggleStatusBar()), actionCollection());
 //  KStdAction::saveOptions(md, SLOT(writeSettings()), actionCollection());
 
+  KAction *action;
+
   (void)new KAction(i18n("&Add..."), QIconSet(BarIcon("add_user")), 0, md,
     SLOT(useradd()), actionCollection(), "add_user");
-  (void)new KAction(i18n("&Edit..."), QIconSet(BarIcon("edit_user")), 0, md,
+
+  action = new KAction(i18n("&Edit..."), QIconSet(BarIcon("edit_user")), 0, md,
     SLOT(useredit()), actionCollection(), "edit_user");
-  (void)new KAction(i18n("&Delete..."), QIconSet(BarIcon("delete_user")), 0, md,
+  connect(md, SIGNAL(userSelected(bool)), action, SLOT(setEnabled(bool)));
+
+  action = new KAction(i18n("&Delete..."), QIconSet(BarIcon("delete_user")), 0, md,
     SLOT(userdel()), actionCollection(), "delete_user");
-  (void)new KAction(i18n("&Set password..."), QIconSet(BarIcon("set_password_user")),
+  connect(md, SIGNAL(userSelected(bool)), action, SLOT(setEnabled(bool)));
+
+  (void)new KAction(i18n("&Set Password..."), QIconSet(BarIcon("set_password_user")),
     0, md, SLOT(setpwd()), actionCollection(), "set_password_user");
 
   (void)new KAction(i18n("&Add..."), QIconSet(BarIcon("add_group")), 0, md,
     SLOT(grpadd()), actionCollection(), "add_group");
-  (void)new KAction(i18n("&Edit..."), QIconSet(BarIcon("edit_group")), 0, md,
+
+  action = new KAction(i18n("&Edit..."), QIconSet(BarIcon("edit_group")), 0, md,
     SLOT(grpedit()), actionCollection(), "edit_group");
-  (void)new KAction(i18n("&Delete..."), QIconSet(BarIcon("delete_group")), 0, md,
+  connect(md, SIGNAL(groupSelected(bool)), action, SLOT(setEnabled(bool)));
+
+  action = new KAction(i18n("&Delete..."), QIconSet(BarIcon("delete_group")), 0, md,
     SLOT(grpdel()), actionCollection(), "delete_group");
+  connect(md, SIGNAL(groupSelected(bool)), action, SLOT(setEnabled(bool)));
 
   createGUI("kuserui.rc");
 }
@@ -108,3 +118,4 @@ void mainWidget::toggleStatusBar() {
     statusBar()->hide();
 }
 
+#include "mainWidget.moc"
