@@ -1,8 +1,8 @@
-#include "globals.h"
 
 #include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
+#include <config.h>
 
 #ifdef HAVE_CRYPT_H
 #include <crypt.h>
@@ -13,7 +13,6 @@
 
 #include "pwddlg.h"
 #include "misc.h"
-#include "globals.h"
 
 pwddlg::pwddlg(KUser *AUser, QWidget* parent, const char* name)
   : KDialogBase(parent, name, true, i18n("Enter Password"), Ok | Cancel, Ok, true), 
