@@ -25,14 +25,14 @@ public:
 
   ~userDefaultsPage();
 
-  const char *getShell() const;
-  const char *getHomeBase() const;
+  QString getShell() const;
+  QString getHomeBase() const;
   bool getCreateHomeDir() const;
   bool getCopySkel() const;
   bool getUserPrivateGroup() const;
 
-  void setShell(const char *data);
-  void setHomeBase(const char *data);
+  void setShell(const QString & data);
+  void setHomeBase(const QString & data);
   void setCreateHomeDir(bool data);
   void setCopySkel(bool data);
   void setUserPrivateGroup(bool data);
