@@ -4,7 +4,7 @@
 #include <klocale.h>
 #include <qtooltip.h>
 #include <qbuttongroup.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <stdlib.h>
 
 AddMessage::AddMessage(ftpaccess *f, bool rdm, 
