@@ -3,12 +3,12 @@
 #include <qlabel.h>
 #include <klocale.h>
 #include <qtooltip.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 AddNoRet::AddNoRet(QWidget * parent, char * wname): QWidget(parent, wname)
 {
 	int y;
-	this->setCaption(i18n("Add non-retrievable file/directory"));
+	this->setCaption(i18n("Add Non-Retrievable File/Directory"));
 	resize(320,80);
 	setFixedSize(320,80);
 	filename=new InputFileCtl(i18n("&Filename:"),0,false,0,this);
@@ -33,8 +33,8 @@ AddNoRet::~AddNoRet()
 }
 void AddNoRet::okButtonPressed()
 {
-	char const * const f=(char const *)filename->text();
-	if(f!=0)
+	QString f = filename->text();
+	if(!f.isNull())
 		emit noRetAdded(f);
 	delete this;
 }
