@@ -13,7 +13,7 @@ public slots:
 	void okButtonPressed();
 	void cancelButtonPressed();
 signals:
-	void noRetAdded(char const * const);
+	void noRetAdded(const QString &);
 private:
 	InputFileCtl *	filename;
 	QPushButton *	ok;
