@@ -3,12 +3,12 @@
 #include <qlabel.h>
 #include <klocale.h>
 #include <qtooltip.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 AddVHost::AddVHost(QWidget * parent, char * wname): QWidget(parent, wname)
 {
 	int y;
-	this->setCaption(i18n("Add virtual host"));
+	this->setCaption(i18n("Add Virtual Host"));
 	resize(320,80);
 	setFixedSize(320,80);
 	IP=new InputCtl(i18n("&IP:"),0,this);
