@@ -15,9 +15,9 @@ public:
     ~EditUpload();
 public slots:
     void chownPressed();
-    void chownToPressed(const char *a);
+    void chownToPressed(QString const &a);
     void chgrpPressed();
-    void chgrpToPressed(const char *a);
+    void chgrpToPressed(QString const &a);
     void okButtonPressed();
     void cancelButtonPressed();
 signals:
