@@ -1,7 +1,7 @@
 #include "Messages.moc"
 #include "AddMessage.h"
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <qwhatsthis.h>
 
 Messages::Messages(QWidget *parent, const char *name): QWidget(parent, name)
@@ -16,9 +16,9 @@ Messages::Messages(QWidget *parent, const char *name): QWidget(parent, name)
 	hostname->setGeometry(x,y,w-10,hostname->height());
 	y+=hostname->height()+5;
 	QWhatsThis::add(hostname,i18n("The hostname given here will be shown at login and for\nthe %L cookie in message files.\nIf this is blank, the canonical hostname of your system will be used."));
-	adminmail=new InputCtl(i18n("E-Mail of &admin (for %E):"),0,this);
+	adminmail=new InputCtl(i18n("Email of &admin (for %E):"),0,this);
 	adminmail->setGeometry(x,y,w-10,adminmail->height());
-	QWhatsThis::add(adminmail,i18n("E-Mail address returned with the %E cookie in message files."));
+	QWhatsThis::add(adminmail,i18n("Email address returned with the %E cookie in message files."));
 	y+=adminmail->height()+5;
 	msgShowEverytime=new QCheckBox(i18n("Show &messages every time"), this);
 	QWhatsThis::add(msgShowEverytime,i18n("If this is not checked, message files at CWD will be displayed only once."));
