@@ -2,14 +2,14 @@
 #include <qwidget.h>
 #include <qlabel.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <qtooltip.h>
 #include <kmessagebox.h>
 
 NewClass::NewClass(QWidget * parent, char * wname): QWidget(parent, wname)
 {
 	int y;
-	this->setCaption(i18n("Add new user class"));
+	this->setCaption(i18n("Add New User Class"));
 	resize(320,130);
 	setFixedSize(320,130);
 	QLabel *lbl1=new QLabel(i18n("New class &name:"), this);
