@@ -2,7 +2,7 @@
 #include "AddDlFree.h"
 #include "ftpaccess.h"
 #include <qlabel.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <qwhatsthis.h>
 
