@@ -19,7 +19,7 @@ public slots:
 	void update();
 	void addNoRetPressed();
 	void delNoRetPressed();
-	void noRetAdded(char const * const filename);
+	void noRetAdded(const QString & filename);
 private:
 	void		redrawNoRetrieves();
 	ftpaccess *	ftpxs;
