@@ -2,7 +2,7 @@
 #include "EditUpload.h"
 #include "AddRCPT.h"
 #include <qlabel.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 
 // getqlbsel: Return number of selected item in a QListBox
