@@ -1,3 +1,6 @@
+#ifndef _VIRTUAL_H_
+#define _VIRTUAL_H_
+
 #include "ftpaccess.h"
 #include "InputFileCtl.h"
 #include "InputCtl.h"
@@ -41,3 +44,4 @@ private:
 	int		curHost;
 };
 
+#endif
