@@ -1,4 +1,5 @@
 #include <qtextstream.h>
+#include <qregexp.h>
 
 #include "ftpaccess.h"
 #include "support.h"
@@ -1525,11 +1526,11 @@ ostream &operator << (ostream &os, ftpupload &f)
 		if(!f.group.isEmpty()) {
 			os << "\t" << f.group.latin1();
 			if(f.mode) {
-				os << "\t0" << oct << f.mode << "\t";
+				os << "\t0" << std::oct << f.mode << "\t";
 				if(f.permitDirs) {
 					os << "dirs";
 					if(f.dMode)
-						os << "\t0" << oct << f.dMode;
+						os << "\t0" << std::oct << f.dMode;
 				} else
 					os << "nodirs";
 			}
