@@ -11,12 +11,11 @@
 #include "Uploads.h"
 #include "Virtual.h"
 #include <kapp.h>
-#include <ktmainwindow.h>
-#include <kwm.h>
+#include <kmainwindow.h>
 #include <klocale.h>
 #include <qtabwidget.h>
 
-class kwuftpd : public KTMainWindow {
+class kwuftpd : public KMainWindow {
 			Q_OBJECT
 public:
 			kwuftpd();
