@@ -96,17 +96,21 @@ void liloconf::set(String const &s)
 void liloconf::writeFile(String const &filename)
 {
 	ofstream f;
-	f.open(filename, ios::out, 0600);
+	f.open(filename, ios::out);
 	f << *this << endl;
 	f.close();
+	chmod(filename, 0600);
 }
 bool liloconf::install(bool probeonly)
 {
 	char *lilotmp=strdup("/tmp/liloXXXXXX");
 	String command;
-	ofstream f;
 	int fd=mkstemp(lilotmp);
-	f.attach(fd);
+	// Unfortunately, gcc 3.1 and higher don't have ofstream::attach
+	// anymore. Pity, used to be immensely useful.
+	// f.attach(fd);
+	close(fd);
+	ofstream f(lilotmp, ios::out);
 	f << defaults << endl;
 	for(liloimages::iterator it=images.begin(); it!=images.end(); it++) {
 		f << *it << endl;
@@ -311,19 +315,29 @@ bool liloconf::probe()
 		case 0xfd: // Linux RAID
 			// TODO: scan other FSes for kernels...
 			break;
-		case 0x84: // OS/2 hidden C:
+		case 0x84:
 		{
-			// CLASH: SystemSoft MobilePRO BIOS uses the same
+			// CLASH: SystemSoft MobilePRO BIOS and
+			// various Dell BIOSes use the same
 			// ID (0x84) for its hibernation partitions
 			// as OS/2 does for hidden C: drives.
 			// Fortunately, hibernation partitions are easy to
 			// recognize...
 			int fd=open(*it, O_RDONLY);
-			char *header=(char *) malloc(10);
-			read(fd, header, 10);
+			char *header=(char *) malloc(20);
+			read(fd, header, 20);
 			close(fd);
 			if(strncmp(header, "SystemSoft", 10)==0) // It's a hibernation partition
 				break;
+			else if(strncmp(header+3, "Dell Suspend", 12)==0) { // It's a Dell hibernation partition
+				// Dell BIOSes are ultimately buggy: They don't do resume-from-disk
+				// properly.
+				// Hibernation partitions are bootable and need to be loaded by the
+				// boot manager instead.
+				addOther("SuspendToDisk", *it);
+				break;
+			}
+			addOther("OS2", *it, false, "/boot/os2_d.b");
 		}
 		case 0x0a: // OS/2 Boot Manager
 			addOther("OS2", *it, false, "/boot/os2_d.b");
