@@ -270,7 +270,7 @@ void Images::saveChanges() // SLOT
 {
 	if(!current.isEmpty()) {
 		liloimage *l=lilo->images[current.latin1()];
-		if(!l) {
+		if(l) {
 			l->set("image", image->text().latin1(), true, true);
 			l->set("label", label->text().latin1(), true, true, "\t");
 			l->set("root", root->text().latin1(), true, true, "\t");
