@@ -43,8 +43,7 @@ extern "C"
 {
   KCModule *create_lilo(QWidget *parent, const char *name)
   {
-    KGlobal::locale()->insertCatalogue("kcmlilo");
-    return new KControl(parent, name);
+    return new KControl(parent, "kcmlilo");
   };
 }
 
