@@ -1,6 +1,6 @@
 #include <kglobal.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmenubar.h>
 #include <kdialog.h>
 #include <dcopclient.h>
@@ -11,10 +11,10 @@
 #include "secpolicywin.h"
 
 SecPolicyWin::SecPolicyWin(const char *name)
-  : KTMainWindow(name)
+  : KMainWindow(0,name)
 {
   view = new PamView(this);
-  setView(view);
+  setCentralWidget(view);
 
   KMenuBar *mBar = menuBar();
   QPopupMenu *fileMenu = new QPopupMenu(this);
